# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StepFEA module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stepfea.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StepFEA
else:
    import _StepFEA

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StepFEA.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StepFEA.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepFEA.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepFEA.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StepFEA.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StepFEA.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StepFEA.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StepFEA.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StepFEA.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StepFEA.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepFEA.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StepFEA.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StepFEA.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepFEA.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepFEA.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepFEA.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StepFEA.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StepFEA:
_StepFEA.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StepFEA.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepElement
import OCC.Core.StepRepr
import OCC.Core.StepBasic
import OCC.Core.StepGeom

from enum import IntEnum
from OCC.Core.Exception import *

StepFEA_Volume = _StepFEA.StepFEA_Volume
StepFEA_Cartesian = _StepFEA.StepFEA_Cartesian
StepFEA_Cylindrical = _StepFEA.StepFEA_Cylindrical
StepFEA_Spherical = _StepFEA.StepFEA_Spherical
StepFEA_XTranslation = _StepFEA.StepFEA_XTranslation
StepFEA_YTranslation = _StepFEA.StepFEA_YTranslation
StepFEA_ZTranslation = _StepFEA.StepFEA_ZTranslation
StepFEA_XRotation = _StepFEA.StepFEA_XRotation
StepFEA_YRotation = _StepFEA.StepFEA_YRotation
StepFEA_ZRotation = _StepFEA.StepFEA_ZRotation
StepFEA_Warp = _StepFEA.StepFEA_Warp
StepFEA_ElementEdge = _StepFEA.StepFEA_ElementEdge
StepFEA_Unspecified = _StepFEA.StepFEA_Unspecified


class StepFEA_ElementVolume(IntEnum):
	StepFEA_Volume = 0
StepFEA_Volume = StepFEA_ElementVolume.StepFEA_Volume

class StepFEA_CoordinateSystemType(IntEnum):
	StepFEA_Cartesian = 0
	StepFEA_Cylindrical = 1
	StepFEA_Spherical = 2
StepFEA_Cartesian = StepFEA_CoordinateSystemType.StepFEA_Cartesian
StepFEA_Cylindrical = StepFEA_CoordinateSystemType.StepFEA_Cylindrical
StepFEA_Spherical = StepFEA_CoordinateSystemType.StepFEA_Spherical

class StepFEA_EnumeratedDegreeOfFreedom(IntEnum):
	StepFEA_XTranslation = 0
	StepFEA_YTranslation = 1
	StepFEA_ZTranslation = 2
	StepFEA_XRotation = 3
	StepFEA_YRotation = 4
	StepFEA_ZRotation = 5
	StepFEA_Warp = 6
StepFEA_XTranslation = StepFEA_EnumeratedDegreeOfFreedom.StepFEA_XTranslation
StepFEA_YTranslation = StepFEA_EnumeratedDegreeOfFreedom.StepFEA_YTranslation
StepFEA_ZTranslation = StepFEA_EnumeratedDegreeOfFreedom.StepFEA_ZTranslation
StepFEA_XRotation = StepFEA_EnumeratedDegreeOfFreedom.StepFEA_XRotation
StepFEA_YRotation = StepFEA_EnumeratedDegreeOfFreedom.StepFEA_YRotation
StepFEA_ZRotation = StepFEA_EnumeratedDegreeOfFreedom.StepFEA_ZRotation
StepFEA_Warp = StepFEA_EnumeratedDegreeOfFreedom.StepFEA_Warp

class StepFEA_CurveEdge(IntEnum):
	StepFEA_ElementEdge = 0
StepFEA_ElementEdge = StepFEA_CurveEdge.StepFEA_ElementEdge

class StepFEA_UnspecifiedValue(IntEnum):
	StepFEA_Unspecified = 0
StepFEA_Unspecified = StepFEA_UnspecifiedValue.StepFEA_Unspecified


def Handle_StepFEA_Curve3dElementProperty_Create() -> "opencascade::handle< StepFEA_Curve3dElementProperty >":
    return _StepFEA.Handle_StepFEA_Curve3dElementProperty_Create()

def Handle_StepFEA_Curve3dElementProperty_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_Curve3dElementProperty >":
    return _StepFEA.Handle_StepFEA_Curve3dElementProperty_DownCast(t)

def Handle_StepFEA_Curve3dElementProperty_IsNull(t: "opencascade::handle< StepFEA_Curve3dElementProperty > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_Curve3dElementProperty_IsNull(t)

def Handle_StepFEA_CurveElementEndOffset_Create() -> "opencascade::handle< StepFEA_CurveElementEndOffset >":
    return _StepFEA.Handle_StepFEA_CurveElementEndOffset_Create()

def Handle_StepFEA_CurveElementEndOffset_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_CurveElementEndOffset >":
    return _StepFEA.Handle_StepFEA_CurveElementEndOffset_DownCast(t)

def Handle_StepFEA_CurveElementEndOffset_IsNull(t: "opencascade::handle< StepFEA_CurveElementEndOffset > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_CurveElementEndOffset_IsNull(t)

def Handle_StepFEA_CurveElementEndRelease_Create() -> "opencascade::handle< StepFEA_CurveElementEndRelease >":
    return _StepFEA.Handle_StepFEA_CurveElementEndRelease_Create()

def Handle_StepFEA_CurveElementEndRelease_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_CurveElementEndRelease >":
    return _StepFEA.Handle_StepFEA_CurveElementEndRelease_DownCast(t)

def Handle_StepFEA_CurveElementEndRelease_IsNull(t: "opencascade::handle< StepFEA_CurveElementEndRelease > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_CurveElementEndRelease_IsNull(t)

def Handle_StepFEA_CurveElementInterval_Create() -> "opencascade::handle< StepFEA_CurveElementInterval >":
    return _StepFEA.Handle_StepFEA_CurveElementInterval_Create()

def Handle_StepFEA_CurveElementInterval_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_CurveElementInterval >":
    return _StepFEA.Handle_StepFEA_CurveElementInterval_DownCast(t)

def Handle_StepFEA_CurveElementInterval_IsNull(t: "opencascade::handle< StepFEA_CurveElementInterval > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_CurveElementInterval_IsNull(t)

def Handle_StepFEA_CurveElementLocation_Create() -> "opencascade::handle< StepFEA_CurveElementLocation >":
    return _StepFEA.Handle_StepFEA_CurveElementLocation_Create()

def Handle_StepFEA_CurveElementLocation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_CurveElementLocation >":
    return _StepFEA.Handle_StepFEA_CurveElementLocation_DownCast(t)

def Handle_StepFEA_CurveElementLocation_IsNull(t: "opencascade::handle< StepFEA_CurveElementLocation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_CurveElementLocation_IsNull(t)

def Handle_StepFEA_DegreeOfFreedomMember_Create() -> "opencascade::handle< StepFEA_DegreeOfFreedomMember >":
    return _StepFEA.Handle_StepFEA_DegreeOfFreedomMember_Create()

def Handle_StepFEA_DegreeOfFreedomMember_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_DegreeOfFreedomMember >":
    return _StepFEA.Handle_StepFEA_DegreeOfFreedomMember_DownCast(t)

def Handle_StepFEA_DegreeOfFreedomMember_IsNull(t: "opencascade::handle< StepFEA_DegreeOfFreedomMember > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_DegreeOfFreedomMember_IsNull(t)

def Handle_StepFEA_ElementGeometricRelationship_Create() -> "opencascade::handle< StepFEA_ElementGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_ElementGeometricRelationship_Create()

def Handle_StepFEA_ElementGeometricRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ElementGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_ElementGeometricRelationship_DownCast(t)

def Handle_StepFEA_ElementGeometricRelationship_IsNull(t: "opencascade::handle< StepFEA_ElementGeometricRelationship > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ElementGeometricRelationship_IsNull(t)

def Handle_StepFEA_ElementRepresentation_Create() -> "opencascade::handle< StepFEA_ElementRepresentation >":
    return _StepFEA.Handle_StepFEA_ElementRepresentation_Create()

def Handle_StepFEA_ElementRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ElementRepresentation >":
    return _StepFEA.Handle_StepFEA_ElementRepresentation_DownCast(t)

def Handle_StepFEA_ElementRepresentation_IsNull(t: "opencascade::handle< StepFEA_ElementRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ElementRepresentation_IsNull(t)

def Handle_StepFEA_FeaAxis2Placement3d_Create() -> "opencascade::handle< StepFEA_FeaAxis2Placement3d >":
    return _StepFEA.Handle_StepFEA_FeaAxis2Placement3d_Create()

def Handle_StepFEA_FeaAxis2Placement3d_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaAxis2Placement3d >":
    return _StepFEA.Handle_StepFEA_FeaAxis2Placement3d_DownCast(t)

def Handle_StepFEA_FeaAxis2Placement3d_IsNull(t: "opencascade::handle< StepFEA_FeaAxis2Placement3d > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaAxis2Placement3d_IsNull(t)

def Handle_StepFEA_FeaCurveSectionGeometricRelationship_Create() -> "opencascade::handle< StepFEA_FeaCurveSectionGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_FeaCurveSectionGeometricRelationship_Create()

def Handle_StepFEA_FeaCurveSectionGeometricRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaCurveSectionGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_FeaCurveSectionGeometricRelationship_DownCast(t)

def Handle_StepFEA_FeaCurveSectionGeometricRelationship_IsNull(t: "opencascade::handle< StepFEA_FeaCurveSectionGeometricRelationship > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaCurveSectionGeometricRelationship_IsNull(t)

def Handle_StepFEA_FeaGroup_Create() -> "opencascade::handle< StepFEA_FeaGroup >":
    return _StepFEA.Handle_StepFEA_FeaGroup_Create()

def Handle_StepFEA_FeaGroup_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaGroup >":
    return _StepFEA.Handle_StepFEA_FeaGroup_DownCast(t)

def Handle_StepFEA_FeaGroup_IsNull(t: "opencascade::handle< StepFEA_FeaGroup > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaGroup_IsNull(t)

def Handle_StepFEA_FeaMaterialPropertyRepresentation_Create() -> "opencascade::handle< StepFEA_FeaMaterialPropertyRepresentation >":
    return _StepFEA.Handle_StepFEA_FeaMaterialPropertyRepresentation_Create()

def Handle_StepFEA_FeaMaterialPropertyRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaMaterialPropertyRepresentation >":
    return _StepFEA.Handle_StepFEA_FeaMaterialPropertyRepresentation_DownCast(t)

def Handle_StepFEA_FeaMaterialPropertyRepresentation_IsNull(t: "opencascade::handle< StepFEA_FeaMaterialPropertyRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaMaterialPropertyRepresentation_IsNull(t)

def Handle_StepFEA_FeaMaterialPropertyRepresentationItem_Create() -> "opencascade::handle< StepFEA_FeaMaterialPropertyRepresentationItem >":
    return _StepFEA.Handle_StepFEA_FeaMaterialPropertyRepresentationItem_Create()

def Handle_StepFEA_FeaMaterialPropertyRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaMaterialPropertyRepresentationItem >":
    return _StepFEA.Handle_StepFEA_FeaMaterialPropertyRepresentationItem_DownCast(t)

def Handle_StepFEA_FeaMaterialPropertyRepresentationItem_IsNull(t: "opencascade::handle< StepFEA_FeaMaterialPropertyRepresentationItem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaMaterialPropertyRepresentationItem_IsNull(t)

def Handle_StepFEA_FeaModel_Create() -> "opencascade::handle< StepFEA_FeaModel >":
    return _StepFEA.Handle_StepFEA_FeaModel_Create()

def Handle_StepFEA_FeaModel_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaModel >":
    return _StepFEA.Handle_StepFEA_FeaModel_DownCast(t)

def Handle_StepFEA_FeaModel_IsNull(t: "opencascade::handle< StepFEA_FeaModel > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaModel_IsNull(t)

def Handle_StepFEA_FeaModelDefinition_Create() -> "opencascade::handle< StepFEA_FeaModelDefinition >":
    return _StepFEA.Handle_StepFEA_FeaModelDefinition_Create()

def Handle_StepFEA_FeaModelDefinition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaModelDefinition >":
    return _StepFEA.Handle_StepFEA_FeaModelDefinition_DownCast(t)

def Handle_StepFEA_FeaModelDefinition_IsNull(t: "opencascade::handle< StepFEA_FeaModelDefinition > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaModelDefinition_IsNull(t)

def Handle_StepFEA_FeaParametricPoint_Create() -> "opencascade::handle< StepFEA_FeaParametricPoint >":
    return _StepFEA.Handle_StepFEA_FeaParametricPoint_Create()

def Handle_StepFEA_FeaParametricPoint_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaParametricPoint >":
    return _StepFEA.Handle_StepFEA_FeaParametricPoint_DownCast(t)

def Handle_StepFEA_FeaParametricPoint_IsNull(t: "opencascade::handle< StepFEA_FeaParametricPoint > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaParametricPoint_IsNull(t)

def Handle_StepFEA_FeaRepresentationItem_Create() -> "opencascade::handle< StepFEA_FeaRepresentationItem >":
    return _StepFEA.Handle_StepFEA_FeaRepresentationItem_Create()

def Handle_StepFEA_FeaRepresentationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaRepresentationItem >":
    return _StepFEA.Handle_StepFEA_FeaRepresentationItem_DownCast(t)

def Handle_StepFEA_FeaRepresentationItem_IsNull(t: "opencascade::handle< StepFEA_FeaRepresentationItem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaRepresentationItem_IsNull(t)

def Handle_StepFEA_FeaSurfaceSectionGeometricRelationship_Create() -> "opencascade::handle< StepFEA_FeaSurfaceSectionGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_FeaSurfaceSectionGeometricRelationship_Create()

def Handle_StepFEA_FeaSurfaceSectionGeometricRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaSurfaceSectionGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_FeaSurfaceSectionGeometricRelationship_DownCast(t)

def Handle_StepFEA_FeaSurfaceSectionGeometricRelationship_IsNull(t: "opencascade::handle< StepFEA_FeaSurfaceSectionGeometricRelationship > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaSurfaceSectionGeometricRelationship_IsNull(t)

def Handle_StepFEA_FreedomAndCoefficient_Create() -> "opencascade::handle< StepFEA_FreedomAndCoefficient >":
    return _StepFEA.Handle_StepFEA_FreedomAndCoefficient_Create()

def Handle_StepFEA_FreedomAndCoefficient_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FreedomAndCoefficient >":
    return _StepFEA.Handle_StepFEA_FreedomAndCoefficient_DownCast(t)

def Handle_StepFEA_FreedomAndCoefficient_IsNull(t: "opencascade::handle< StepFEA_FreedomAndCoefficient > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FreedomAndCoefficient_IsNull(t)

def Handle_StepFEA_FreedomsList_Create() -> "opencascade::handle< StepFEA_FreedomsList >":
    return _StepFEA.Handle_StepFEA_FreedomsList_Create()

def Handle_StepFEA_FreedomsList_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FreedomsList >":
    return _StepFEA.Handle_StepFEA_FreedomsList_DownCast(t)

def Handle_StepFEA_FreedomsList_IsNull(t: "opencascade::handle< StepFEA_FreedomsList > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FreedomsList_IsNull(t)

def Handle_StepFEA_NodeDefinition_Create() -> "opencascade::handle< StepFEA_NodeDefinition >":
    return _StepFEA.Handle_StepFEA_NodeDefinition_Create()

def Handle_StepFEA_NodeDefinition_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_NodeDefinition >":
    return _StepFEA.Handle_StepFEA_NodeDefinition_DownCast(t)

def Handle_StepFEA_NodeDefinition_IsNull(t: "opencascade::handle< StepFEA_NodeDefinition > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_NodeDefinition_IsNull(t)

def Handle_StepFEA_NodeRepresentation_Create() -> "opencascade::handle< StepFEA_NodeRepresentation >":
    return _StepFEA.Handle_StepFEA_NodeRepresentation_Create()

def Handle_StepFEA_NodeRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_NodeRepresentation >":
    return _StepFEA.Handle_StepFEA_NodeRepresentation_DownCast(t)

def Handle_StepFEA_NodeRepresentation_IsNull(t: "opencascade::handle< StepFEA_NodeRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_NodeRepresentation_IsNull(t)

def Handle_StepFEA_NodeSet_Create() -> "opencascade::handle< StepFEA_NodeSet >":
    return _StepFEA.Handle_StepFEA_NodeSet_Create()

def Handle_StepFEA_NodeSet_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_NodeSet >":
    return _StepFEA.Handle_StepFEA_NodeSet_DownCast(t)

def Handle_StepFEA_NodeSet_IsNull(t: "opencascade::handle< StepFEA_NodeSet > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_NodeSet_IsNull(t)

def Handle_StepFEA_SymmetricTensor23dMember_Create() -> "opencascade::handle< StepFEA_SymmetricTensor23dMember >":
    return _StepFEA.Handle_StepFEA_SymmetricTensor23dMember_Create()

def Handle_StepFEA_SymmetricTensor23dMember_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_SymmetricTensor23dMember >":
    return _StepFEA.Handle_StepFEA_SymmetricTensor23dMember_DownCast(t)

def Handle_StepFEA_SymmetricTensor23dMember_IsNull(t: "opencascade::handle< StepFEA_SymmetricTensor23dMember > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_SymmetricTensor23dMember_IsNull(t)

def Handle_StepFEA_SymmetricTensor43dMember_Create() -> "opencascade::handle< StepFEA_SymmetricTensor43dMember >":
    return _StepFEA.Handle_StepFEA_SymmetricTensor43dMember_Create()

def Handle_StepFEA_SymmetricTensor43dMember_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_SymmetricTensor43dMember >":
    return _StepFEA.Handle_StepFEA_SymmetricTensor43dMember_DownCast(t)

def Handle_StepFEA_SymmetricTensor43dMember_IsNull(t: "opencascade::handle< StepFEA_SymmetricTensor43dMember > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_SymmetricTensor43dMember_IsNull(t)

def Handle_StepFEA_AlignedCurve3dElementCoordinateSystem_Create() -> "opencascade::handle< StepFEA_AlignedCurve3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_AlignedCurve3dElementCoordinateSystem_Create()

def Handle_StepFEA_AlignedCurve3dElementCoordinateSystem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_AlignedCurve3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_AlignedCurve3dElementCoordinateSystem_DownCast(t)

def Handle_StepFEA_AlignedCurve3dElementCoordinateSystem_IsNull(t: "opencascade::handle< StepFEA_AlignedCurve3dElementCoordinateSystem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_AlignedCurve3dElementCoordinateSystem_IsNull(t)

def Handle_StepFEA_AlignedSurface3dElementCoordinateSystem_Create() -> "opencascade::handle< StepFEA_AlignedSurface3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_AlignedSurface3dElementCoordinateSystem_Create()

def Handle_StepFEA_AlignedSurface3dElementCoordinateSystem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_AlignedSurface3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_AlignedSurface3dElementCoordinateSystem_DownCast(t)

def Handle_StepFEA_AlignedSurface3dElementCoordinateSystem_IsNull(t: "opencascade::handle< StepFEA_AlignedSurface3dElementCoordinateSystem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_AlignedSurface3dElementCoordinateSystem_IsNull(t)

def Handle_StepFEA_ArbitraryVolume3dElementCoordinateSystem_Create() -> "opencascade::handle< StepFEA_ArbitraryVolume3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ArbitraryVolume3dElementCoordinateSystem_Create()

def Handle_StepFEA_ArbitraryVolume3dElementCoordinateSystem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ArbitraryVolume3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ArbitraryVolume3dElementCoordinateSystem_DownCast(t)

def Handle_StepFEA_ArbitraryVolume3dElementCoordinateSystem_IsNull(t: "opencascade::handle< StepFEA_ArbitraryVolume3dElementCoordinateSystem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ArbitraryVolume3dElementCoordinateSystem_IsNull(t)

def Handle_StepFEA_ConstantSurface3dElementCoordinateSystem_Create() -> "opencascade::handle< StepFEA_ConstantSurface3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ConstantSurface3dElementCoordinateSystem_Create()

def Handle_StepFEA_ConstantSurface3dElementCoordinateSystem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ConstantSurface3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ConstantSurface3dElementCoordinateSystem_DownCast(t)

def Handle_StepFEA_ConstantSurface3dElementCoordinateSystem_IsNull(t: "opencascade::handle< StepFEA_ConstantSurface3dElementCoordinateSystem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ConstantSurface3dElementCoordinateSystem_IsNull(t)

def Handle_StepFEA_Curve3dElementRepresentation_Create() -> "opencascade::handle< StepFEA_Curve3dElementRepresentation >":
    return _StepFEA.Handle_StepFEA_Curve3dElementRepresentation_Create()

def Handle_StepFEA_Curve3dElementRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_Curve3dElementRepresentation >":
    return _StepFEA.Handle_StepFEA_Curve3dElementRepresentation_DownCast(t)

def Handle_StepFEA_Curve3dElementRepresentation_IsNull(t: "opencascade::handle< StepFEA_Curve3dElementRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_Curve3dElementRepresentation_IsNull(t)

def Handle_StepFEA_CurveElementIntervalConstant_Create() -> "opencascade::handle< StepFEA_CurveElementIntervalConstant >":
    return _StepFEA.Handle_StepFEA_CurveElementIntervalConstant_Create()

def Handle_StepFEA_CurveElementIntervalConstant_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_CurveElementIntervalConstant >":
    return _StepFEA.Handle_StepFEA_CurveElementIntervalConstant_DownCast(t)

def Handle_StepFEA_CurveElementIntervalConstant_IsNull(t: "opencascade::handle< StepFEA_CurveElementIntervalConstant > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_CurveElementIntervalConstant_IsNull(t)

def Handle_StepFEA_CurveElementIntervalLinearlyVarying_Create() -> "opencascade::handle< StepFEA_CurveElementIntervalLinearlyVarying >":
    return _StepFEA.Handle_StepFEA_CurveElementIntervalLinearlyVarying_Create()

def Handle_StepFEA_CurveElementIntervalLinearlyVarying_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_CurveElementIntervalLinearlyVarying >":
    return _StepFEA.Handle_StepFEA_CurveElementIntervalLinearlyVarying_DownCast(t)

def Handle_StepFEA_CurveElementIntervalLinearlyVarying_IsNull(t: "opencascade::handle< StepFEA_CurveElementIntervalLinearlyVarying > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_CurveElementIntervalLinearlyVarying_IsNull(t)

def Handle_StepFEA_DummyNode_Create() -> "opencascade::handle< StepFEA_DummyNode >":
    return _StepFEA.Handle_StepFEA_DummyNode_Create()

def Handle_StepFEA_DummyNode_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_DummyNode >":
    return _StepFEA.Handle_StepFEA_DummyNode_DownCast(t)

def Handle_StepFEA_DummyNode_IsNull(t: "opencascade::handle< StepFEA_DummyNode > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_DummyNode_IsNull(t)

def Handle_StepFEA_ElementGroup_Create() -> "opencascade::handle< StepFEA_ElementGroup >":
    return _StepFEA.Handle_StepFEA_ElementGroup_Create()

def Handle_StepFEA_ElementGroup_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ElementGroup >":
    return _StepFEA.Handle_StepFEA_ElementGroup_DownCast(t)

def Handle_StepFEA_ElementGroup_IsNull(t: "opencascade::handle< StepFEA_ElementGroup > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ElementGroup_IsNull(t)

def Handle_StepFEA_FeaAreaDensity_Create() -> "opencascade::handle< StepFEA_FeaAreaDensity >":
    return _StepFEA.Handle_StepFEA_FeaAreaDensity_Create()

def Handle_StepFEA_FeaAreaDensity_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaAreaDensity >":
    return _StepFEA.Handle_StepFEA_FeaAreaDensity_DownCast(t)

def Handle_StepFEA_FeaAreaDensity_IsNull(t: "opencascade::handle< StepFEA_FeaAreaDensity > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaAreaDensity_IsNull(t)

def Handle_StepFEA_FeaLinearElasticity_Create() -> "opencascade::handle< StepFEA_FeaLinearElasticity >":
    return _StepFEA.Handle_StepFEA_FeaLinearElasticity_Create()

def Handle_StepFEA_FeaLinearElasticity_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaLinearElasticity >":
    return _StepFEA.Handle_StepFEA_FeaLinearElasticity_DownCast(t)

def Handle_StepFEA_FeaLinearElasticity_IsNull(t: "opencascade::handle< StepFEA_FeaLinearElasticity > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaLinearElasticity_IsNull(t)

def Handle_StepFEA_FeaMassDensity_Create() -> "opencascade::handle< StepFEA_FeaMassDensity >":
    return _StepFEA.Handle_StepFEA_FeaMassDensity_Create()

def Handle_StepFEA_FeaMassDensity_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaMassDensity >":
    return _StepFEA.Handle_StepFEA_FeaMassDensity_DownCast(t)

def Handle_StepFEA_FeaMassDensity_IsNull(t: "opencascade::handle< StepFEA_FeaMassDensity > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaMassDensity_IsNull(t)

def Handle_StepFEA_FeaModel3d_Create() -> "opencascade::handle< StepFEA_FeaModel3d >":
    return _StepFEA.Handle_StepFEA_FeaModel3d_Create()

def Handle_StepFEA_FeaModel3d_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaModel3d >":
    return _StepFEA.Handle_StepFEA_FeaModel3d_DownCast(t)

def Handle_StepFEA_FeaModel3d_IsNull(t: "opencascade::handle< StepFEA_FeaModel3d > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaModel3d_IsNull(t)

def Handle_StepFEA_FeaMoistureAbsorption_Create() -> "opencascade::handle< StepFEA_FeaMoistureAbsorption >":
    return _StepFEA.Handle_StepFEA_FeaMoistureAbsorption_Create()

def Handle_StepFEA_FeaMoistureAbsorption_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaMoistureAbsorption >":
    return _StepFEA.Handle_StepFEA_FeaMoistureAbsorption_DownCast(t)

def Handle_StepFEA_FeaMoistureAbsorption_IsNull(t: "opencascade::handle< StepFEA_FeaMoistureAbsorption > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaMoistureAbsorption_IsNull(t)

def Handle_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_Create() -> "opencascade::handle< StepFEA_FeaSecantCoefficientOfLinearThermalExpansion >":
    return _StepFEA.Handle_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_Create()

def Handle_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaSecantCoefficientOfLinearThermalExpansion >":
    return _StepFEA.Handle_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_DownCast(t)

def Handle_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_IsNull(t: "opencascade::handle< StepFEA_FeaSecantCoefficientOfLinearThermalExpansion > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_IsNull(t)

def Handle_StepFEA_FeaShellBendingStiffness_Create() -> "opencascade::handle< StepFEA_FeaShellBendingStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellBendingStiffness_Create()

def Handle_StepFEA_FeaShellBendingStiffness_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaShellBendingStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellBendingStiffness_DownCast(t)

def Handle_StepFEA_FeaShellBendingStiffness_IsNull(t: "opencascade::handle< StepFEA_FeaShellBendingStiffness > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaShellBendingStiffness_IsNull(t)

def Handle_StepFEA_FeaShellMembraneBendingCouplingStiffness_Create() -> "opencascade::handle< StepFEA_FeaShellMembraneBendingCouplingStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellMembraneBendingCouplingStiffness_Create()

def Handle_StepFEA_FeaShellMembraneBendingCouplingStiffness_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaShellMembraneBendingCouplingStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellMembraneBendingCouplingStiffness_DownCast(t)

def Handle_StepFEA_FeaShellMembraneBendingCouplingStiffness_IsNull(t: "opencascade::handle< StepFEA_FeaShellMembraneBendingCouplingStiffness > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaShellMembraneBendingCouplingStiffness_IsNull(t)

def Handle_StepFEA_FeaShellMembraneStiffness_Create() -> "opencascade::handle< StepFEA_FeaShellMembraneStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellMembraneStiffness_Create()

def Handle_StepFEA_FeaShellMembraneStiffness_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaShellMembraneStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellMembraneStiffness_DownCast(t)

def Handle_StepFEA_FeaShellMembraneStiffness_IsNull(t: "opencascade::handle< StepFEA_FeaShellMembraneStiffness > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaShellMembraneStiffness_IsNull(t)

def Handle_StepFEA_FeaShellShearStiffness_Create() -> "opencascade::handle< StepFEA_FeaShellShearStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellShearStiffness_Create()

def Handle_StepFEA_FeaShellShearStiffness_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaShellShearStiffness >":
    return _StepFEA.Handle_StepFEA_FeaShellShearStiffness_DownCast(t)

def Handle_StepFEA_FeaShellShearStiffness_IsNull(t: "opencascade::handle< StepFEA_FeaShellShearStiffness > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaShellShearStiffness_IsNull(t)

def Handle_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_Create() -> "opencascade::handle< StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion >":
    return _StepFEA.Handle_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_Create()

def Handle_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion >":
    return _StepFEA.Handle_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_DownCast(t)

def Handle_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_IsNull(t: "opencascade::handle< StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_IsNull(t)

def Handle_StepFEA_GeometricNode_Create() -> "opencascade::handle< StepFEA_GeometricNode >":
    return _StepFEA.Handle_StepFEA_GeometricNode_Create()

def Handle_StepFEA_GeometricNode_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_GeometricNode >":
    return _StepFEA.Handle_StepFEA_GeometricNode_DownCast(t)

def Handle_StepFEA_GeometricNode_IsNull(t: "opencascade::handle< StepFEA_GeometricNode > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_GeometricNode_IsNull(t)

def Handle_StepFEA_Node_Create() -> "opencascade::handle< StepFEA_Node >":
    return _StepFEA.Handle_StepFEA_Node_Create()

def Handle_StepFEA_Node_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_Node >":
    return _StepFEA.Handle_StepFEA_Node_DownCast(t)

def Handle_StepFEA_Node_IsNull(t: "opencascade::handle< StepFEA_Node > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_Node_IsNull(t)

def Handle_StepFEA_NodeGroup_Create() -> "opencascade::handle< StepFEA_NodeGroup >":
    return _StepFEA.Handle_StepFEA_NodeGroup_Create()

def Handle_StepFEA_NodeGroup_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_NodeGroup >":
    return _StepFEA.Handle_StepFEA_NodeGroup_DownCast(t)

def Handle_StepFEA_NodeGroup_IsNull(t: "opencascade::handle< StepFEA_NodeGroup > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_NodeGroup_IsNull(t)

def Handle_StepFEA_ParametricCurve3dElementCoordinateDirection_Create() -> "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateDirection >":
    return _StepFEA.Handle_StepFEA_ParametricCurve3dElementCoordinateDirection_Create()

def Handle_StepFEA_ParametricCurve3dElementCoordinateDirection_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateDirection >":
    return _StepFEA.Handle_StepFEA_ParametricCurve3dElementCoordinateDirection_DownCast(t)

def Handle_StepFEA_ParametricCurve3dElementCoordinateDirection_IsNull(t: "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateDirection > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ParametricCurve3dElementCoordinateDirection_IsNull(t)

def Handle_StepFEA_ParametricCurve3dElementCoordinateSystem_Create() -> "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ParametricCurve3dElementCoordinateSystem_Create()

def Handle_StepFEA_ParametricCurve3dElementCoordinateSystem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ParametricCurve3dElementCoordinateSystem_DownCast(t)

def Handle_StepFEA_ParametricCurve3dElementCoordinateSystem_IsNull(t: "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateSystem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ParametricCurve3dElementCoordinateSystem_IsNull(t)

def Handle_StepFEA_ParametricSurface3dElementCoordinateSystem_Create() -> "opencascade::handle< StepFEA_ParametricSurface3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ParametricSurface3dElementCoordinateSystem_Create()

def Handle_StepFEA_ParametricSurface3dElementCoordinateSystem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_ParametricSurface3dElementCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_ParametricSurface3dElementCoordinateSystem_DownCast(t)

def Handle_StepFEA_ParametricSurface3dElementCoordinateSystem_IsNull(t: "opencascade::handle< StepFEA_ParametricSurface3dElementCoordinateSystem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_ParametricSurface3dElementCoordinateSystem_IsNull(t)

def Handle_StepFEA_Surface3dElementRepresentation_Create() -> "opencascade::handle< StepFEA_Surface3dElementRepresentation >":
    return _StepFEA.Handle_StepFEA_Surface3dElementRepresentation_Create()

def Handle_StepFEA_Surface3dElementRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_Surface3dElementRepresentation >":
    return _StepFEA.Handle_StepFEA_Surface3dElementRepresentation_DownCast(t)

def Handle_StepFEA_Surface3dElementRepresentation_IsNull(t: "opencascade::handle< StepFEA_Surface3dElementRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_Surface3dElementRepresentation_IsNull(t)

def Handle_StepFEA_Volume3dElementRepresentation_Create() -> "opencascade::handle< StepFEA_Volume3dElementRepresentation >":
    return _StepFEA.Handle_StepFEA_Volume3dElementRepresentation_Create()

def Handle_StepFEA_Volume3dElementRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_Volume3dElementRepresentation >":
    return _StepFEA.Handle_StepFEA_Volume3dElementRepresentation_DownCast(t)

def Handle_StepFEA_Volume3dElementRepresentation_IsNull(t: "opencascade::handle< StepFEA_Volume3dElementRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_Volume3dElementRepresentation_IsNull(t)

def Handle_StepFEA_NodeWithSolutionCoordinateSystem_Create() -> "opencascade::handle< StepFEA_NodeWithSolutionCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_NodeWithSolutionCoordinateSystem_Create()

def Handle_StepFEA_NodeWithSolutionCoordinateSystem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_NodeWithSolutionCoordinateSystem >":
    return _StepFEA.Handle_StepFEA_NodeWithSolutionCoordinateSystem_DownCast(t)

def Handle_StepFEA_NodeWithSolutionCoordinateSystem_IsNull(t: "opencascade::handle< StepFEA_NodeWithSolutionCoordinateSystem > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_NodeWithSolutionCoordinateSystem_IsNull(t)

def Handle_StepFEA_NodeWithVector_Create() -> "opencascade::handle< StepFEA_NodeWithVector >":
    return _StepFEA.Handle_StepFEA_NodeWithVector_Create()

def Handle_StepFEA_NodeWithVector_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_NodeWithVector >":
    return _StepFEA.Handle_StepFEA_NodeWithVector_DownCast(t)

def Handle_StepFEA_NodeWithVector_IsNull(t: "opencascade::handle< StepFEA_NodeWithVector > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_NodeWithVector_IsNull(t)

def Handle_StepFEA_HArray1OfCurveElementInterval_Create() -> "opencascade::handle< StepFEA_HArray1OfCurveElementInterval >":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementInterval_Create()

def Handle_StepFEA_HArray1OfCurveElementInterval_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HArray1OfCurveElementInterval >":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementInterval_DownCast(t)

def Handle_StepFEA_HArray1OfCurveElementInterval_IsNull(t: "opencascade::handle< StepFEA_HArray1OfCurveElementInterval > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementInterval_IsNull(t)

def Handle_StepFEA_HArray1OfCurveElementEndOffset_Create() -> "opencascade::handle< StepFEA_HArray1OfCurveElementEndOffset >":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementEndOffset_Create()

def Handle_StepFEA_HArray1OfCurveElementEndOffset_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HArray1OfCurveElementEndOffset >":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementEndOffset_DownCast(t)

def Handle_StepFEA_HArray1OfCurveElementEndOffset_IsNull(t: "opencascade::handle< StepFEA_HArray1OfCurveElementEndOffset > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementEndOffset_IsNull(t)

def Handle_StepFEA_HArray1OfElementRepresentation_Create() -> "opencascade::handle< StepFEA_HArray1OfElementRepresentation >":
    return _StepFEA.Handle_StepFEA_HArray1OfElementRepresentation_Create()

def Handle_StepFEA_HArray1OfElementRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HArray1OfElementRepresentation >":
    return _StepFEA.Handle_StepFEA_HArray1OfElementRepresentation_DownCast(t)

def Handle_StepFEA_HArray1OfElementRepresentation_IsNull(t: "opencascade::handle< StepFEA_HArray1OfElementRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HArray1OfElementRepresentation_IsNull(t)

def Handle_StepFEA_HArray1OfCurveElementEndRelease_Create() -> "opencascade::handle< StepFEA_HArray1OfCurveElementEndRelease >":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementEndRelease_Create()

def Handle_StepFEA_HArray1OfCurveElementEndRelease_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HArray1OfCurveElementEndRelease >":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementEndRelease_DownCast(t)

def Handle_StepFEA_HArray1OfCurveElementEndRelease_IsNull(t: "opencascade::handle< StepFEA_HArray1OfCurveElementEndRelease > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HArray1OfCurveElementEndRelease_IsNull(t)

def Handle_StepFEA_HArray1OfDegreeOfFreedom_Create() -> "opencascade::handle< StepFEA_HArray1OfDegreeOfFreedom >":
    return _StepFEA.Handle_StepFEA_HArray1OfDegreeOfFreedom_Create()

def Handle_StepFEA_HArray1OfDegreeOfFreedom_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HArray1OfDegreeOfFreedom >":
    return _StepFEA.Handle_StepFEA_HArray1OfDegreeOfFreedom_DownCast(t)

def Handle_StepFEA_HArray1OfDegreeOfFreedom_IsNull(t: "opencascade::handle< StepFEA_HArray1OfDegreeOfFreedom > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HArray1OfDegreeOfFreedom_IsNull(t)

def Handle_StepFEA_HArray1OfNodeRepresentation_Create() -> "opencascade::handle< StepFEA_HArray1OfNodeRepresentation >":
    return _StepFEA.Handle_StepFEA_HArray1OfNodeRepresentation_Create()

def Handle_StepFEA_HArray1OfNodeRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HArray1OfNodeRepresentation >":
    return _StepFEA.Handle_StepFEA_HArray1OfNodeRepresentation_DownCast(t)

def Handle_StepFEA_HArray1OfNodeRepresentation_IsNull(t: "opencascade::handle< StepFEA_HArray1OfNodeRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HArray1OfNodeRepresentation_IsNull(t)

def Handle_StepFEA_HSequenceOfElementRepresentation_Create() -> "opencascade::handle< StepFEA_HSequenceOfElementRepresentation >":
    return _StepFEA.Handle_StepFEA_HSequenceOfElementRepresentation_Create()

def Handle_StepFEA_HSequenceOfElementRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HSequenceOfElementRepresentation >":
    return _StepFEA.Handle_StepFEA_HSequenceOfElementRepresentation_DownCast(t)

def Handle_StepFEA_HSequenceOfElementRepresentation_IsNull(t: "opencascade::handle< StepFEA_HSequenceOfElementRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HSequenceOfElementRepresentation_IsNull(t)

def Handle_StepFEA_HSequenceOfElementGeometricRelationship_Create() -> "opencascade::handle< StepFEA_HSequenceOfElementGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_HSequenceOfElementGeometricRelationship_Create()

def Handle_StepFEA_HSequenceOfElementGeometricRelationship_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HSequenceOfElementGeometricRelationship >":
    return _StepFEA.Handle_StepFEA_HSequenceOfElementGeometricRelationship_DownCast(t)

def Handle_StepFEA_HSequenceOfElementGeometricRelationship_IsNull(t: "opencascade::handle< StepFEA_HSequenceOfElementGeometricRelationship > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HSequenceOfElementGeometricRelationship_IsNull(t)

def Handle_StepFEA_HSequenceOfNodeRepresentation_Create() -> "opencascade::handle< StepFEA_HSequenceOfNodeRepresentation >":
    return _StepFEA.Handle_StepFEA_HSequenceOfNodeRepresentation_Create()

def Handle_StepFEA_HSequenceOfNodeRepresentation_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HSequenceOfNodeRepresentation >":
    return _StepFEA.Handle_StepFEA_HSequenceOfNodeRepresentation_DownCast(t)

def Handle_StepFEA_HSequenceOfNodeRepresentation_IsNull(t: "opencascade::handle< StepFEA_HSequenceOfNodeRepresentation > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HSequenceOfNodeRepresentation_IsNull(t)

def Handle_StepFEA_HSequenceOfCurve3dElementProperty_Create() -> "opencascade::handle< StepFEA_HSequenceOfCurve3dElementProperty >":
    return _StepFEA.Handle_StepFEA_HSequenceOfCurve3dElementProperty_Create()

def Handle_StepFEA_HSequenceOfCurve3dElementProperty_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepFEA_HSequenceOfCurve3dElementProperty >":
    return _StepFEA.Handle_StepFEA_HSequenceOfCurve3dElementProperty_DownCast(t)

def Handle_StepFEA_HSequenceOfCurve3dElementProperty_IsNull(t: "opencascade::handle< StepFEA_HSequenceOfCurve3dElementProperty > const &") -> "bool":
    return _StepFEA.Handle_StepFEA_HSequenceOfCurve3dElementProperty_IsNull(t)
class StepFEA_Array1OfCurveElementEndOffset(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndOffset > >::iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndOffset > >::iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndOffset > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndOffset > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_Array1OfCurveElementEndOffset_swiginit(self, _StepFEA.new_StepFEA_Array1OfCurveElementEndOffset(*args))

    def Init(self, theValue: "opencascade::handle< StepFEA_CurveElementEndOffset > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_IsAllocated(self)

    def Assign(self, theOther: "StepFEA_Array1OfCurveElementEndOffset") -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndOffset > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Assign(self, theOther)

    def Move(self, theOther: "StepFEA_Array1OfCurveElementEndOffset") -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndOffset > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndOffset > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Set(self, *args)

    def First(self) -> "opencascade::handle< StepFEA_CurveElementEndOffset > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_CurveElementEndOffset > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_CurveElementEndOffset > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_CurveElementEndOffset > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_CurveElementEndOffset > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_CurveElementEndOffset > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_CurveElementEndOffset > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_CurveElementEndOffset > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementEndOffset_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepFEA.delete_StepFEA_Array1OfCurveElementEndOffset

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepFEA_Array1OfCurveElementEndOffset in _StepFEA:
_StepFEA.StepFEA_Array1OfCurveElementEndOffset_swigregister(StepFEA_Array1OfCurveElementEndOffset)

class StepFEA_Array1OfCurveElementEndRelease(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndRelease > >::iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndRelease > >::iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndRelease > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndRelease > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_Array1OfCurveElementEndRelease_swiginit(self, _StepFEA.new_StepFEA_Array1OfCurveElementEndRelease(*args))

    def Init(self, theValue: "opencascade::handle< StepFEA_CurveElementEndRelease > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_IsAllocated(self)

    def Assign(self, theOther: "StepFEA_Array1OfCurveElementEndRelease") -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndRelease > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Assign(self, theOther)

    def Move(self, theOther: "StepFEA_Array1OfCurveElementEndRelease") -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndRelease > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementEndRelease > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Set(self, *args)

    def First(self) -> "opencascade::handle< StepFEA_CurveElementEndRelease > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_CurveElementEndRelease > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_CurveElementEndRelease > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_CurveElementEndRelease > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_CurveElementEndRelease > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_CurveElementEndRelease > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_CurveElementEndRelease > &":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_CurveElementEndRelease > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementEndRelease_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepFEA.delete_StepFEA_Array1OfCurveElementEndRelease

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepFEA_Array1OfCurveElementEndRelease in _StepFEA:
_StepFEA.StepFEA_Array1OfCurveElementEndRelease_swigregister(StepFEA_Array1OfCurveElementEndRelease)

class StepFEA_Array1OfCurveElementInterval(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementInterval > >::iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementInterval > >::iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementInterval > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementInterval > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_Array1OfCurveElementInterval_swiginit(self, _StepFEA.new_StepFEA_Array1OfCurveElementInterval(*args))

    def Init(self, theValue: "opencascade::handle< StepFEA_CurveElementInterval > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_IsAllocated(self)

    def Assign(self, theOther: "StepFEA_Array1OfCurveElementInterval") -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementInterval > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Assign(self, theOther)

    def Move(self, theOther: "StepFEA_Array1OfCurveElementInterval") -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementInterval > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepFEA_CurveElementInterval > > &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Set(self, *args)

    def First(self) -> "opencascade::handle< StepFEA_CurveElementInterval > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_CurveElementInterval > &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_CurveElementInterval > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_CurveElementInterval > &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_CurveElementInterval > const &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_CurveElementInterval > &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_CurveElementInterval > &":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_CurveElementInterval > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepFEA.StepFEA_Array1OfCurveElementInterval_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepFEA.delete_StepFEA_Array1OfCurveElementInterval

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepFEA_Array1OfCurveElementInterval in _StepFEA:
_StepFEA.StepFEA_Array1OfCurveElementInterval_swigregister(StepFEA_Array1OfCurveElementInterval)

class StepFEA_Array1OfDegreeOfFreedom(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepFEA_DegreeOfFreedom >::iterator":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_begin(self)

    def end(self) -> "NCollection_Array1< StepFEA_DegreeOfFreedom >::iterator":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_end(self)

    def cbegin(self) -> "NCollection_Array1< StepFEA_DegreeOfFreedom >::const_iterator":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepFEA_DegreeOfFreedom >::const_iterator":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_Array1OfDegreeOfFreedom_swiginit(self, _StepFEA.new_StepFEA_Array1OfDegreeOfFreedom(*args))

    def Init(self, theValue: "StepFEA_DegreeOfFreedom") -> "void":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_IsAllocated(self)

    def Assign(self, theOther: "StepFEA_Array1OfDegreeOfFreedom") -> "NCollection_Array1< StepFEA_DegreeOfFreedom > &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Assign(self, theOther)

    def Move(self, theOther: "StepFEA_Array1OfDegreeOfFreedom") -> "NCollection_Array1< StepFEA_DegreeOfFreedom > &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepFEA_DegreeOfFreedom > &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Set(self, *args)

    def First(self) -> "StepFEA_DegreeOfFreedom const &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_First(self)

    def ChangeFirst(self) -> "StepFEA_DegreeOfFreedom &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_ChangeFirst(self)

    def Last(self) -> "StepFEA_DegreeOfFreedom const &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Last(self)

    def ChangeLast(self) -> "StepFEA_DegreeOfFreedom &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepFEA_DegreeOfFreedom const &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepFEA_DegreeOfFreedom &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepFEA_DegreeOfFreedom &":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepFEA_DegreeOfFreedom") -> "void":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepFEA.StepFEA_Array1OfDegreeOfFreedom_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepFEA.delete_StepFEA_Array1OfDegreeOfFreedom

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepFEA_Array1OfDegreeOfFreedom in _StepFEA:
_StepFEA.StepFEA_Array1OfDegreeOfFreedom_swigregister(StepFEA_Array1OfDegreeOfFreedom)

class StepFEA_Array1OfElementRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_ElementRepresentation > >::iterator":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepFEA_ElementRepresentation > >::iterator":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_ElementRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepFEA_ElementRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_Array1OfElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_Array1OfElementRepresentation(*args))

    def Init(self, theValue: "opencascade::handle< StepFEA_ElementRepresentation > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_IsAllocated(self)

    def Assign(self, theOther: "StepFEA_Array1OfElementRepresentation") -> "NCollection_Array1< opencascade::handle< StepFEA_ElementRepresentation > > &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Assign(self, theOther)

    def Move(self, theOther: "StepFEA_Array1OfElementRepresentation") -> "NCollection_Array1< opencascade::handle< StepFEA_ElementRepresentation > > &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepFEA_ElementRepresentation > > &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Set(self, *args)

    def First(self) -> "opencascade::handle< StepFEA_ElementRepresentation > const &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_ElementRepresentation > const &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_ElementRepresentation > const &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_Array1OfElementRepresentation___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_ElementRepresentation > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepFEA.StepFEA_Array1OfElementRepresentation_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepFEA.delete_StepFEA_Array1OfElementRepresentation

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepFEA_Array1OfElementRepresentation in _StepFEA:
_StepFEA.StepFEA_Array1OfElementRepresentation_swigregister(StepFEA_Array1OfElementRepresentation)

class StepFEA_Array1OfNodeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_NodeRepresentation > >::iterator":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< StepFEA_NodeRepresentation > >::iterator":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< StepFEA_NodeRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< StepFEA_NodeRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_Array1OfNodeRepresentation_swiginit(self, _StepFEA.new_StepFEA_Array1OfNodeRepresentation(*args))

    def Init(self, theValue: "opencascade::handle< StepFEA_NodeRepresentation > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_IsAllocated(self)

    def Assign(self, theOther: "StepFEA_Array1OfNodeRepresentation") -> "NCollection_Array1< opencascade::handle< StepFEA_NodeRepresentation > > &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Assign(self, theOther)

    def Move(self, theOther: "StepFEA_Array1OfNodeRepresentation") -> "NCollection_Array1< opencascade::handle< StepFEA_NodeRepresentation > > &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< StepFEA_NodeRepresentation > > &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Set(self, *args)

    def First(self) -> "opencascade::handle< StepFEA_NodeRepresentation > const &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_NodeRepresentation > const &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_NodeRepresentation > const &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_NodeRepresentation > const &") -> "void":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepFEA.StepFEA_Array1OfNodeRepresentation_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepFEA.delete_StepFEA_Array1OfNodeRepresentation

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepFEA_Array1OfNodeRepresentation in _StepFEA:
_StepFEA.StepFEA_Array1OfNodeRepresentation_swigregister(StepFEA_Array1OfNodeRepresentation)

class StepFEA_SequenceOfCurve3dElementProperty(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_Curve3dElementProperty > >::iterator":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_Curve3dElementProperty > >::iterator":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_Curve3dElementProperty > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_Curve3dElementProperty > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_swiginit(self, _StepFEA.new_StepFEA_SequenceOfCurve3dElementProperty(*args))

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_IsEmpty(self)

    def Reverse(self) -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Clear(self, theAllocator)

    def Assign(self, theOther: "StepFEA_SequenceOfCurve3dElementProperty") -> "NCollection_Sequence< opencascade::handle< StepFEA_Curve3dElementProperty > > &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Assign(self, theOther)

    def Set(self, theOther: "StepFEA_SequenceOfCurve3dElementProperty") -> "NCollection_Sequence< opencascade::handle< StepFEA_Curve3dElementProperty > > &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "StepFEA_SequenceOfCurve3dElementProperty") -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< StepFEA_Curve3dElementProperty > const &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_Curve3dElementProperty > &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_Curve3dElementProperty > const &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_Curve3dElementProperty > &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_Curve3dElementProperty > const &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_Curve3dElementProperty > &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_Curve3dElementProperty > &":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_Curve3dElementProperty > const &") -> "void":
        return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _StepFEA.delete_StepFEA_SequenceOfCurve3dElementProperty

    def __len__(self):
        return self.Size()


# Register StepFEA_SequenceOfCurve3dElementProperty in _StepFEA:
_StepFEA.StepFEA_SequenceOfCurve3dElementProperty_swigregister(StepFEA_SequenceOfCurve3dElementProperty)

def StepFEA_SequenceOfCurve3dElementProperty_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _StepFEA.StepFEA_SequenceOfCurve3dElementProperty_delNode(theNode, theAl)

class StepFEA_SequenceOfElementGeometricRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementGeometricRelationship > >::iterator":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementGeometricRelationship > >::iterator":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementGeometricRelationship > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementGeometricRelationship > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_swiginit(self, _StepFEA.new_StepFEA_SequenceOfElementGeometricRelationship(*args))

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_IsEmpty(self)

    def Reverse(self) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Clear(self, theAllocator)

    def Assign(self, theOther: "StepFEA_SequenceOfElementGeometricRelationship") -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementGeometricRelationship > > &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Assign(self, theOther)

    def Set(self, theOther: "StepFEA_SequenceOfElementGeometricRelationship") -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementGeometricRelationship > > &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "StepFEA_SequenceOfElementGeometricRelationship") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< StepFEA_ElementGeometricRelationship > const &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_ElementGeometricRelationship > &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_ElementGeometricRelationship > const &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_ElementGeometricRelationship > &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_ElementGeometricRelationship > const &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_ElementGeometricRelationship > &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_ElementGeometricRelationship > &":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_ElementGeometricRelationship > const &") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _StepFEA.delete_StepFEA_SequenceOfElementGeometricRelationship

    def __len__(self):
        return self.Size()


# Register StepFEA_SequenceOfElementGeometricRelationship in _StepFEA:
_StepFEA.StepFEA_SequenceOfElementGeometricRelationship_swigregister(StepFEA_SequenceOfElementGeometricRelationship)

def StepFEA_SequenceOfElementGeometricRelationship_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _StepFEA.StepFEA_SequenceOfElementGeometricRelationship_delNode(theNode, theAl)

class StepFEA_SequenceOfElementRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementRepresentation > >::iterator":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementRepresentation > >::iterator":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_SequenceOfElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_SequenceOfElementRepresentation(*args))

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_IsEmpty(self)

    def Reverse(self) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Clear(self, theAllocator)

    def Assign(self, theOther: "StepFEA_SequenceOfElementRepresentation") -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementRepresentation > > &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Assign(self, theOther)

    def Set(self, theOther: "StepFEA_SequenceOfElementRepresentation") -> "NCollection_Sequence< opencascade::handle< StepFEA_ElementRepresentation > > &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "StepFEA_SequenceOfElementRepresentation") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< StepFEA_ElementRepresentation > const &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_ElementRepresentation > const &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_ElementRepresentation > const &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_ElementRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_ElementRepresentation > const &") -> "void":
        return _StepFEA.StepFEA_SequenceOfElementRepresentation_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _StepFEA.delete_StepFEA_SequenceOfElementRepresentation

    def __len__(self):
        return self.Size()


# Register StepFEA_SequenceOfElementRepresentation in _StepFEA:
_StepFEA.StepFEA_SequenceOfElementRepresentation_swigregister(StepFEA_SequenceOfElementRepresentation)

def StepFEA_SequenceOfElementRepresentation_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _StepFEA.StepFEA_SequenceOfElementRepresentation_delNode(theNode, theAl)

class StepFEA_SequenceOfNodeRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_NodeRepresentation > >::iterator":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_NodeRepresentation > >::iterator":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_NodeRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< StepFEA_NodeRepresentation > >::const_iterator":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_cend(self)

    def __init__(self, *args):
        _StepFEA.StepFEA_SequenceOfNodeRepresentation_swiginit(self, _StepFEA.new_StepFEA_SequenceOfNodeRepresentation(*args))

    def Size(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_IsEmpty(self)

    def Reverse(self) -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Clear(self, theAllocator)

    def Assign(self, theOther: "StepFEA_SequenceOfNodeRepresentation") -> "NCollection_Sequence< opencascade::handle< StepFEA_NodeRepresentation > > &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Assign(self, theOther)

    def Set(self, theOther: "StepFEA_SequenceOfNodeRepresentation") -> "NCollection_Sequence< opencascade::handle< StepFEA_NodeRepresentation > > &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "StepFEA_SequenceOfNodeRepresentation") -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< StepFEA_NodeRepresentation > const &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_First(self)

    def ChangeFirst(self) -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< StepFEA_NodeRepresentation > const &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Last(self)

    def ChangeLast(self) -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_NodeRepresentation > const &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< StepFEA_NodeRepresentation > &":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< StepFEA_NodeRepresentation > const &") -> "void":
        return _StepFEA.StepFEA_SequenceOfNodeRepresentation_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _StepFEA.delete_StepFEA_SequenceOfNodeRepresentation

    def __len__(self):
        return self.Size()


# Register StepFEA_SequenceOfNodeRepresentation in _StepFEA:
_StepFEA.StepFEA_SequenceOfNodeRepresentation_swigregister(StepFEA_SequenceOfNodeRepresentation)

def StepFEA_SequenceOfNodeRepresentation_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _StepFEA.StepFEA_SequenceOfNodeRepresentation_delNode(theNode, theAl)

class StepFEA_Curve3dElementProperty(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_Curve3dElementProperty_swiginit(self, _StepFEA.new_StepFEA_Curve3dElementProperty(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_Description(self, *args)

    def EndOffsets(self, *args) -> "opencascade::handle< StepFEA_HArray1OfCurveElementEndOffset >":
        r"""
        Returns field endoffsets.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfCurveElementEndOffset>

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_EndOffsets(self, *args)

    def EndReleases(self, *args) -> "opencascade::handle< StepFEA_HArray1OfCurveElementEndRelease >":
        r"""
        Returns field endreleases.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfCurveElementEndRelease>

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_EndReleases(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aPropertyId: TCollection_HAsciiString
        aDescription: TCollection_HAsciiString
        aIntervalDefinitions: StepFEA_HArray1OfCurveElementInterval
        aEndOffsets: StepFEA_HArray1OfCurveElementEndOffset
        aEndReleases: StepFEA_HArray1OfCurveElementEndRelease

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_Init(self, *args)

    def IntervalDefinitions(self, *args) -> "opencascade::handle< StepFEA_HArray1OfCurveElementInterval >":
        r"""
        Returns field intervaldefinitions.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfCurveElementInterval>

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_IntervalDefinitions(self, *args)

    def PropertyId(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field propertyid.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_PropertyId(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_SetDescription(self, *args)

    def SetEndOffsets(self, *args) -> "void":
        r"""
        Set field endoffsets.

        Parameters
        ----------
        EndOffsets: StepFEA_HArray1OfCurveElementEndOffset

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_SetEndOffsets(self, *args)

    def SetEndReleases(self, *args) -> "void":
        r"""
        Set field endreleases.

        Parameters
        ----------
        EndReleases: StepFEA_HArray1OfCurveElementEndRelease

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_SetEndReleases(self, *args)

    def SetIntervalDefinitions(self, *args) -> "void":
        r"""
        Set field intervaldefinitions.

        Parameters
        ----------
        IntervalDefinitions: StepFEA_HArray1OfCurveElementInterval

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_SetIntervalDefinitions(self, *args)

    def SetPropertyId(self, *args) -> "void":
        r"""
        Set field propertyid.

        Parameters
        ----------
        PropertyId: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementProperty_SetPropertyId(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_Curve3dElementProperty_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_Curve3dElementProperty

# Register StepFEA_Curve3dElementProperty in _StepFEA:
_StepFEA.StepFEA_Curve3dElementProperty_swigregister(StepFEA_Curve3dElementProperty)

class StepFEA_CurveElementEndCoordinateSystem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_CurveElementEndCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_CurveElementEndCoordinateSystem(*args))

    def AlignedCurve3dElementCoordinateSystem(self, *args) -> "opencascade::handle< StepFEA_AlignedCurve3dElementCoordinateSystem >":
        r"""
        Returns value as alignedcurve3delementcoordinatesystem (or null if another type).

        Returns
        -------
        opencascade::handle<StepFEA_AlignedCurve3dElementCoordinateSystem>

        """
        return _StepFEA.StepFEA_CurveElementEndCoordinateSystem_AlignedCurve3dElementCoordinateSystem(self, *args)

    def FeaAxis2Placement3d(self, *args) -> "opencascade::handle< StepFEA_FeaAxis2Placement3d >":
        r"""
        Returns value as feaaxis2placement3d (or null if another type).

        Returns
        -------
        opencascade::handle<StepFEA_FeaAxis2Placement3d>

        """
        return _StepFEA.StepFEA_CurveElementEndCoordinateSystem_FeaAxis2Placement3d(self, *args)

    def ParametricCurve3dElementCoordinateSystem(self, *args) -> "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateSystem >":
        r"""
        Returns value as parametriccurve3delementcoordinatesystem (or null if another type).

        Returns
        -------
        opencascade::handle<StepFEA_ParametricCurve3dElementCoordinateSystem>

        """
        return _StepFEA.StepFEA_CurveElementEndCoordinateSystem_ParametricCurve3dElementCoordinateSystem(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_CurveElementEndCoordinateSystem

# Register StepFEA_CurveElementEndCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_CurveElementEndCoordinateSystem_swigregister(StepFEA_CurveElementEndCoordinateSystem)

class StepFEA_CurveElementEndOffset(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_CurveElementEndOffset_swiginit(self, _StepFEA.new_StepFEA_CurveElementEndOffset(*args))

    def CoordinateSystem(self, *args) -> "StepFEA_CurveElementEndCoordinateSystem":
        r"""
        Returns field coordinatesystem.

        Returns
        -------
        StepFEA_CurveElementEndCoordinateSystem

        """
        return _StepFEA.StepFEA_CurveElementEndOffset_CoordinateSystem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aCoordinateSystem: StepFEA_CurveElementEndCoordinateSystem
        aOffsetVector: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementEndOffset_Init(self, *args)

    def OffsetVector(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns field offsetvector.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_CurveElementEndOffset_OffsetVector(self, *args)

    def SetCoordinateSystem(self, *args) -> "void":
        r"""
        Set field coordinatesystem.

        Parameters
        ----------
        CoordinateSystem: StepFEA_CurveElementEndCoordinateSystem

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementEndOffset_SetCoordinateSystem(self, *args)

    def SetOffsetVector(self, *args) -> "void":
        r"""
        Set field offsetvector.

        Parameters
        ----------
        OffsetVector: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementEndOffset_SetOffsetVector(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_CurveElementEndOffset_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_CurveElementEndOffset

# Register StepFEA_CurveElementEndOffset in _StepFEA:
_StepFEA.StepFEA_CurveElementEndOffset_swigregister(StepFEA_CurveElementEndOffset)

class StepFEA_CurveElementEndRelease(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_CurveElementEndRelease_swiginit(self, _StepFEA.new_StepFEA_CurveElementEndRelease(*args))

    def CoordinateSystem(self, *args) -> "StepFEA_CurveElementEndCoordinateSystem":
        r"""
        Returns field coordinatesystem.

        Returns
        -------
        StepFEA_CurveElementEndCoordinateSystem

        """
        return _StepFEA.StepFEA_CurveElementEndRelease_CoordinateSystem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aCoordinateSystem: StepFEA_CurveElementEndCoordinateSystem
        aReleases: StepElement_HArray1OfCurveElementEndReleasePacket

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementEndRelease_Init(self, *args)

    def Releases(self, *args) -> "opencascade::handle< StepElement_HArray1OfCurveElementEndReleasePacket >":
        r"""
        Returns field releases.

        Returns
        -------
        opencascade::handle<StepElement_HArray1OfCurveElementEndReleasePacket>

        """
        return _StepFEA.StepFEA_CurveElementEndRelease_Releases(self, *args)

    def SetCoordinateSystem(self, *args) -> "void":
        r"""
        Set field coordinatesystem.

        Parameters
        ----------
        CoordinateSystem: StepFEA_CurveElementEndCoordinateSystem

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementEndRelease_SetCoordinateSystem(self, *args)

    def SetReleases(self, *args) -> "void":
        r"""
        Set field releases.

        Parameters
        ----------
        Releases: StepElement_HArray1OfCurveElementEndReleasePacket

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementEndRelease_SetReleases(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_CurveElementEndRelease_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_CurveElementEndRelease

# Register StepFEA_CurveElementEndRelease in _StepFEA:
_StepFEA.StepFEA_CurveElementEndRelease_swigregister(StepFEA_CurveElementEndRelease)

class StepFEA_CurveElementInterval(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_CurveElementInterval_swiginit(self, _StepFEA.new_StepFEA_CurveElementInterval(*args))

    def EuAngles(self, *args) -> "opencascade::handle< StepBasic_EulerAngles >":
        r"""
        Returns field euangles.

        Returns
        -------
        opencascade::handle<StepBasic_EulerAngles>

        """
        return _StepFEA.StepFEA_CurveElementInterval_EuAngles(self, *args)

    def FinishPosition(self, *args) -> "opencascade::handle< StepFEA_CurveElementLocation >":
        r"""
        Returns field finishposition.

        Returns
        -------
        opencascade::handle<StepFEA_CurveElementLocation>

        """
        return _StepFEA.StepFEA_CurveElementInterval_FinishPosition(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aFinishPosition: StepFEA_CurveElementLocation
        aEuAngles: StepBasic_EulerAngles

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementInterval_Init(self, *args)

    def SetEuAngles(self, *args) -> "void":
        r"""
        Set field euangles.

        Parameters
        ----------
        EuAngles: StepBasic_EulerAngles

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementInterval_SetEuAngles(self, *args)

    def SetFinishPosition(self, *args) -> "void":
        r"""
        Set field finishposition.

        Parameters
        ----------
        FinishPosition: StepFEA_CurveElementLocation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementInterval_SetFinishPosition(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_CurveElementInterval_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_CurveElementInterval

# Register StepFEA_CurveElementInterval in _StepFEA:
_StepFEA.StepFEA_CurveElementInterval_swigregister(StepFEA_CurveElementInterval)

class StepFEA_CurveElementLocation(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_CurveElementLocation_swiginit(self, _StepFEA.new_StepFEA_CurveElementLocation(*args))

    def Coordinate(self, *args) -> "opencascade::handle< StepFEA_FeaParametricPoint >":
        r"""
        Returns field coordinate.

        Returns
        -------
        opencascade::handle<StepFEA_FeaParametricPoint>

        """
        return _StepFEA.StepFEA_CurveElementLocation_Coordinate(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aCoordinate: StepFEA_FeaParametricPoint

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementLocation_Init(self, *args)

    def SetCoordinate(self, *args) -> "void":
        r"""
        Set field coordinate.

        Parameters
        ----------
        Coordinate: StepFEA_FeaParametricPoint

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementLocation_SetCoordinate(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_CurveElementLocation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_CurveElementLocation

# Register StepFEA_CurveElementLocation in _StepFEA:
_StepFEA.StepFEA_CurveElementLocation_swigregister(StepFEA_CurveElementLocation)

class StepFEA_DegreeOfFreedom(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_DegreeOfFreedom_swiginit(self, _StepFEA.new_StepFEA_DegreeOfFreedom(*args))

    def ApplicationDefinedDegreeOfFreedom(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns value as applicationdefineddegreeoffreedom (or null if another type).

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepFEA.StepFEA_DegreeOfFreedom_ApplicationDefinedDegreeOfFreedom(self, *args)

    def EnumeratedDegreeOfFreedom(self, *args) -> "StepFEA_EnumeratedDegreeOfFreedom":
        r"""
        Returns value as enumerateddegreeoffreedom (or null if another type).

        Returns
        -------
        StepFEA_EnumeratedDegreeOfFreedom

        """
        return _StepFEA.StepFEA_DegreeOfFreedom_EnumeratedDegreeOfFreedom(self, *args)

    def SetApplicationDefinedDegreeOfFreedom(self, *args) -> "void":
        r"""
        Set value for applicationdefineddegreeoffreedom.

        Parameters
        ----------
        aVal: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_DegreeOfFreedom_SetApplicationDefinedDegreeOfFreedom(self, *args)

    def SetEnumeratedDegreeOfFreedom(self, *args) -> "void":
        r"""
        Returns value as enumerateddegreeoffreedom (or null if another type).

        Parameters
        ----------
        aVal: StepFEA_EnumeratedDegreeOfFreedom

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_DegreeOfFreedom_SetEnumeratedDegreeOfFreedom(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_DegreeOfFreedom

# Register StepFEA_DegreeOfFreedom in _StepFEA:
_StepFEA.StepFEA_DegreeOfFreedom_swigregister(StepFEA_DegreeOfFreedom)

class StepFEA_DegreeOfFreedomMember(OCC.Core.StepData.StepData_SelectNamed):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_DegreeOfFreedomMember_swiginit(self, _StepFEA.new_StepFEA_DegreeOfFreedomMember(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_DegreeOfFreedomMember_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_DegreeOfFreedomMember

# Register StepFEA_DegreeOfFreedomMember in _StepFEA:
_StepFEA.StepFEA_DegreeOfFreedomMember_swigregister(StepFEA_DegreeOfFreedomMember)

class StepFEA_ElementGeometricRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ElementGeometricRelationship_swiginit(self, _StepFEA.new_StepFEA_ElementGeometricRelationship(*args))

    def Aspect(self, *args) -> "StepElement_ElementAspect":
        r"""
        Returns field aspect.

        Returns
        -------
        StepElement_ElementAspect

        """
        return _StepFEA.StepFEA_ElementGeometricRelationship_Aspect(self, *args)

    def ElementRef(self, *args) -> "StepFEA_ElementOrElementGroup":
        r"""
        Returns field elementref.

        Returns
        -------
        StepFEA_ElementOrElementGroup

        """
        return _StepFEA.StepFEA_ElementGeometricRelationship_ElementRef(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aElementRef: StepFEA_ElementOrElementGroup
        aItem: StepElement_AnalysisItemWithinRepresentation
        aAspect: StepElement_ElementAspect

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementGeometricRelationship_Init(self, *args)

    def Item(self, *args) -> "opencascade::handle< StepElement_AnalysisItemWithinRepresentation >":
        r"""
        Returns field item.

        Returns
        -------
        opencascade::handle<StepElement_AnalysisItemWithinRepresentation>

        """
        return _StepFEA.StepFEA_ElementGeometricRelationship_Item(self, *args)

    def SetAspect(self, *args) -> "void":
        r"""
        Set field aspect.

        Parameters
        ----------
        Aspect: StepElement_ElementAspect

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementGeometricRelationship_SetAspect(self, *args)

    def SetElementRef(self, *args) -> "void":
        r"""
        Set field elementref.

        Parameters
        ----------
        ElementRef: StepFEA_ElementOrElementGroup

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementGeometricRelationship_SetElementRef(self, *args)

    def SetItem(self, *args) -> "void":
        r"""
        Set field item.

        Parameters
        ----------
        Item: StepElement_AnalysisItemWithinRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementGeometricRelationship_SetItem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ElementGeometricRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ElementGeometricRelationship

# Register StepFEA_ElementGeometricRelationship in _StepFEA:
_StepFEA.StepFEA_ElementGeometricRelationship_swigregister(StepFEA_ElementGeometricRelationship)

class StepFEA_ElementOrElementGroup(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ElementOrElementGroup_swiginit(self, _StepFEA.new_StepFEA_ElementOrElementGroup(*args))

    def ElementGroup(self, *args) -> "opencascade::handle< StepFEA_ElementGroup >":
        r"""
        Returns value as elementgroup (or null if another type).

        Returns
        -------
        opencascade::handle<StepFEA_ElementGroup>

        """
        return _StepFEA.StepFEA_ElementOrElementGroup_ElementGroup(self, *args)

    def ElementRepresentation(self, *args) -> "opencascade::handle< StepFEA_ElementRepresentation >":
        r"""
        Returns value as elementrepresentation (or null if another type).

        Returns
        -------
        opencascade::handle<StepFEA_ElementRepresentation>

        """
        return _StepFEA.StepFEA_ElementOrElementGroup_ElementRepresentation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ElementOrElementGroup

# Register StepFEA_ElementOrElementGroup in _StepFEA:
_StepFEA.StepFEA_ElementOrElementGroup_swigregister(StepFEA_ElementOrElementGroup)

class StepFEA_ElementRepresentation(OCC.Core.StepRepr.StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_ElementRepresentation(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentation_Name: TCollection_HAsciiString
        aRepresentation_Items: StepRepr_HArray1OfRepresentationItem
        aRepresentation_ContextOfItems: StepRepr_RepresentationContext
        aNodeList: StepFEA_HArray1OfNodeRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementRepresentation_Init(self, *args)

    def NodeList(self, *args) -> "opencascade::handle< StepFEA_HArray1OfNodeRepresentation >":
        r"""
        Returns field nodelist.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfNodeRepresentation>

        """
        return _StepFEA.StepFEA_ElementRepresentation_NodeList(self, *args)

    def SetNodeList(self, *args) -> "void":
        r"""
        Set field nodelist.

        Parameters
        ----------
        NodeList: StepFEA_HArray1OfNodeRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementRepresentation_SetNodeList(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ElementRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ElementRepresentation

# Register StepFEA_ElementRepresentation in _StepFEA:
_StepFEA.StepFEA_ElementRepresentation_swigregister(StepFEA_ElementRepresentation)

class StepFEA_FeaAxis2Placement3d(OCC.Core.StepGeom.StepGeom_Axis2Placement3d):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaAxis2Placement3d_swiginit(self, _StepFEA.new_StepFEA_FeaAxis2Placement3d(*args))

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepFEA.StepFEA_FeaAxis2Placement3d_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aPlacement_Location: StepGeom_CartesianPoint
        hasAxis2Placement3d_Axis: bool
        aAxis2Placement3d_Axis: StepGeom_Direction
        hasAxis2Placement3d_RefDirection: bool
        aAxis2Placement3d_RefDirection: StepGeom_Direction
        aSystemType: StepFEA_CoordinateSystemType
        aDescription: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaAxis2Placement3d_Init(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaAxis2Placement3d_SetDescription(self, *args)

    def SetSystemType(self, *args) -> "void":
        r"""
        Set field systemtype.

        Parameters
        ----------
        SystemType: StepFEA_CoordinateSystemType

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaAxis2Placement3d_SetSystemType(self, *args)

    def SystemType(self, *args) -> "StepFEA_CoordinateSystemType":
        r"""
        Returns field systemtype.

        Returns
        -------
        StepFEA_CoordinateSystemType

        """
        return _StepFEA.StepFEA_FeaAxis2Placement3d_SystemType(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaAxis2Placement3d_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaAxis2Placement3d

# Register StepFEA_FeaAxis2Placement3d in _StepFEA:
_StepFEA.StepFEA_FeaAxis2Placement3d_swigregister(StepFEA_FeaAxis2Placement3d)

class StepFEA_FeaCurveSectionGeometricRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaCurveSectionGeometricRelationship_swiginit(self, _StepFEA.new_StepFEA_FeaCurveSectionGeometricRelationship(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aSectionRef: StepElement_CurveElementSectionDefinition
        aItem: StepElement_AnalysisItemWithinRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaCurveSectionGeometricRelationship_Init(self, *args)

    def Item(self, *args) -> "opencascade::handle< StepElement_AnalysisItemWithinRepresentation >":
        r"""
        Returns field item.

        Returns
        -------
        opencascade::handle<StepElement_AnalysisItemWithinRepresentation>

        """
        return _StepFEA.StepFEA_FeaCurveSectionGeometricRelationship_Item(self, *args)

    def SectionRef(self, *args) -> "opencascade::handle< StepElement_CurveElementSectionDefinition >":
        r"""
        Returns field sectionref.

        Returns
        -------
        opencascade::handle<StepElement_CurveElementSectionDefinition>

        """
        return _StepFEA.StepFEA_FeaCurveSectionGeometricRelationship_SectionRef(self, *args)

    def SetItem(self, *args) -> "void":
        r"""
        Set field item.

        Parameters
        ----------
        Item: StepElement_AnalysisItemWithinRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaCurveSectionGeometricRelationship_SetItem(self, *args)

    def SetSectionRef(self, *args) -> "void":
        r"""
        Set field sectionref.

        Parameters
        ----------
        SectionRef: StepElement_CurveElementSectionDefinition

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaCurveSectionGeometricRelationship_SetSectionRef(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaCurveSectionGeometricRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaCurveSectionGeometricRelationship

# Register StepFEA_FeaCurveSectionGeometricRelationship in _StepFEA:
_StepFEA.StepFEA_FeaCurveSectionGeometricRelationship_swigregister(StepFEA_FeaCurveSectionGeometricRelationship)

class StepFEA_FeaGroup(OCC.Core.StepBasic.StepBasic_Group):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaGroup_swiginit(self, _StepFEA.new_StepFEA_FeaGroup(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aGroup_Name: TCollection_HAsciiString
        aGroup_Description: TCollection_HAsciiString
        aModelRef: StepFEA_FeaModel

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaGroup_Init(self, *args)

    def ModelRef(self, *args) -> "opencascade::handle< StepFEA_FeaModel >":
        r"""
        Returns field modelref.

        Returns
        -------
        opencascade::handle<StepFEA_FeaModel>

        """
        return _StepFEA.StepFEA_FeaGroup_ModelRef(self, *args)

    def SetModelRef(self, *args) -> "void":
        r"""
        Set field modelref.

        Parameters
        ----------
        ModelRef: StepFEA_FeaModel

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaGroup_SetModelRef(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaGroup_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaGroup

# Register StepFEA_FeaGroup in _StepFEA:
_StepFEA.StepFEA_FeaGroup_swigregister(StepFEA_FeaGroup)

class StepFEA_FeaMaterialPropertyRepresentation(OCC.Core.StepRepr.StepRepr_MaterialPropertyRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaMaterialPropertyRepresentation_swiginit(self, _StepFEA.new_StepFEA_FeaMaterialPropertyRepresentation(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaMaterialPropertyRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaMaterialPropertyRepresentation

# Register StepFEA_FeaMaterialPropertyRepresentation in _StepFEA:
_StepFEA.StepFEA_FeaMaterialPropertyRepresentation_swigregister(StepFEA_FeaMaterialPropertyRepresentation)

class StepFEA_FeaMaterialPropertyRepresentationItem(OCC.Core.StepRepr.StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaMaterialPropertyRepresentationItem_swiginit(self, _StepFEA.new_StepFEA_FeaMaterialPropertyRepresentationItem(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaMaterialPropertyRepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaMaterialPropertyRepresentationItem

# Register StepFEA_FeaMaterialPropertyRepresentationItem in _StepFEA:
_StepFEA.StepFEA_FeaMaterialPropertyRepresentationItem_swigregister(StepFEA_FeaMaterialPropertyRepresentationItem)

class StepFEA_FeaModel(OCC.Core.StepRepr.StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaModel_swiginit(self, _StepFEA.new_StepFEA_FeaModel(*args))

    def AnalysisType(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field analysistype.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepFEA.StepFEA_FeaModel_AnalysisType(self, *args)

    def CreatingSoftware(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field creatingsoftware.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepFEA.StepFEA_FeaModel_CreatingSoftware(self, *args)

    def Description(self, *args) -> "opencascade::handle< TCollection_HAsciiString >":
        r"""
        Returns field description.

        Returns
        -------
        opencascade::handle<TCollection_HAsciiString>

        """
        return _StepFEA.StepFEA_FeaModel_Description(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentation_Name: TCollection_HAsciiString
        aRepresentation_Items: StepRepr_HArray1OfRepresentationItem
        aRepresentation_ContextOfItems: StepRepr_RepresentationContext
        aCreatingSoftware: TCollection_HAsciiString
        aIntendedAnalysisCode: TColStd_HArray1OfAsciiString
        aDescription: TCollection_HAsciiString
        aAnalysisType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaModel_Init(self, *args)

    def IntendedAnalysisCode(self, *args) -> "opencascade::handle< TColStd_HArray1OfAsciiString >":
        r"""
        Returns field intendedanalysiscode.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfAsciiString>

        """
        return _StepFEA.StepFEA_FeaModel_IntendedAnalysisCode(self, *args)

    def SetAnalysisType(self, *args) -> "void":
        r"""
        Set field analysistype.

        Parameters
        ----------
        AnalysisType: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaModel_SetAnalysisType(self, *args)

    def SetCreatingSoftware(self, *args) -> "void":
        r"""
        Set field creatingsoftware.

        Parameters
        ----------
        CreatingSoftware: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaModel_SetCreatingSoftware(self, *args)

    def SetDescription(self, *args) -> "void":
        r"""
        Set field description.

        Parameters
        ----------
        Description: TCollection_HAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaModel_SetDescription(self, *args)

    def SetIntendedAnalysisCode(self, *args) -> "void":
        r"""
        Set field intendedanalysiscode.

        Parameters
        ----------
        IntendedAnalysisCode: TColStd_HArray1OfAsciiString

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaModel_SetIntendedAnalysisCode(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaModel_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaModel

# Register StepFEA_FeaModel in _StepFEA:
_StepFEA.StepFEA_FeaModel_swigregister(StepFEA_FeaModel)

class StepFEA_FeaModelDefinition(OCC.Core.StepRepr.StepRepr_ShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaModelDefinition_swiginit(self, _StepFEA.new_StepFEA_FeaModelDefinition(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaModelDefinition_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaModelDefinition

# Register StepFEA_FeaModelDefinition in _StepFEA:
_StepFEA.StepFEA_FeaModelDefinition_swigregister(StepFEA_FeaModelDefinition)

class StepFEA_FeaParametricPoint(OCC.Core.StepGeom.StepGeom_Point):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaParametricPoint_swiginit(self, _StepFEA.new_StepFEA_FeaParametricPoint(*args))

    def Coordinates(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns field coordinates.

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_FeaParametricPoint_Coordinates(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aCoordinates: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaParametricPoint_Init(self, *args)

    def SetCoordinates(self, *args) -> "void":
        r"""
        Set field coordinates.

        Parameters
        ----------
        Coordinates: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaParametricPoint_SetCoordinates(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaParametricPoint_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaParametricPoint

# Register StepFEA_FeaParametricPoint in _StepFEA:
_StepFEA.StepFEA_FeaParametricPoint_swigregister(StepFEA_FeaParametricPoint)

class StepFEA_FeaRepresentationItem(OCC.Core.StepRepr.StepRepr_RepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaRepresentationItem_swiginit(self, _StepFEA.new_StepFEA_FeaRepresentationItem(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaRepresentationItem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaRepresentationItem

# Register StepFEA_FeaRepresentationItem in _StepFEA:
_StepFEA.StepFEA_FeaRepresentationItem_swigregister(StepFEA_FeaRepresentationItem)

class StepFEA_FeaSurfaceSectionGeometricRelationship(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaSurfaceSectionGeometricRelationship_swiginit(self, _StepFEA.new_StepFEA_FeaSurfaceSectionGeometricRelationship(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aSectionRef: StepElement_SurfaceSection
        aItem: StepElement_AnalysisItemWithinRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaSurfaceSectionGeometricRelationship_Init(self, *args)

    def Item(self, *args) -> "opencascade::handle< StepElement_AnalysisItemWithinRepresentation >":
        r"""
        Returns field item.

        Returns
        -------
        opencascade::handle<StepElement_AnalysisItemWithinRepresentation>

        """
        return _StepFEA.StepFEA_FeaSurfaceSectionGeometricRelationship_Item(self, *args)

    def SectionRef(self, *args) -> "opencascade::handle< StepElement_SurfaceSection >":
        r"""
        Returns field sectionref.

        Returns
        -------
        opencascade::handle<StepElement_SurfaceSection>

        """
        return _StepFEA.StepFEA_FeaSurfaceSectionGeometricRelationship_SectionRef(self, *args)

    def SetItem(self, *args) -> "void":
        r"""
        Set field item.

        Parameters
        ----------
        Item: StepElement_AnalysisItemWithinRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaSurfaceSectionGeometricRelationship_SetItem(self, *args)

    def SetSectionRef(self, *args) -> "void":
        r"""
        Set field sectionref.

        Parameters
        ----------
        SectionRef: StepElement_SurfaceSection

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaSurfaceSectionGeometricRelationship_SetSectionRef(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaSurfaceSectionGeometricRelationship_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaSurfaceSectionGeometricRelationship

# Register StepFEA_FeaSurfaceSectionGeometricRelationship in _StepFEA:
_StepFEA.StepFEA_FeaSurfaceSectionGeometricRelationship_swigregister(StepFEA_FeaSurfaceSectionGeometricRelationship)

class StepFEA_FreedomAndCoefficient(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FreedomAndCoefficient_swiginit(self, _StepFEA.new_StepFEA_FreedomAndCoefficient(*args))

    def A(self, *args) -> "StepElement_MeasureOrUnspecifiedValue":
        r"""
        Returns field a.

        Returns
        -------
        StepElement_MeasureOrUnspecifiedValue

        """
        return _StepFEA.StepFEA_FreedomAndCoefficient_A(self, *args)

    def Freedom(self, *args) -> "StepFEA_DegreeOfFreedom":
        r"""
        Returns field freedom.

        Returns
        -------
        StepFEA_DegreeOfFreedom

        """
        return _StepFEA.StepFEA_FreedomAndCoefficient_Freedom(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aFreedom: StepFEA_DegreeOfFreedom
        aA: StepElement_MeasureOrUnspecifiedValue

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FreedomAndCoefficient_Init(self, *args)

    def SetA(self, *args) -> "void":
        r"""
        Set field a.

        Parameters
        ----------
        A: StepElement_MeasureOrUnspecifiedValue

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FreedomAndCoefficient_SetA(self, *args)

    def SetFreedom(self, *args) -> "void":
        r"""
        Set field freedom.

        Parameters
        ----------
        Freedom: StepFEA_DegreeOfFreedom

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FreedomAndCoefficient_SetFreedom(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FreedomAndCoefficient_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FreedomAndCoefficient

# Register StepFEA_FreedomAndCoefficient in _StepFEA:
_StepFEA.StepFEA_FreedomAndCoefficient_swigregister(StepFEA_FreedomAndCoefficient)

class StepFEA_FreedomsList(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FreedomsList_swiginit(self, _StepFEA.new_StepFEA_FreedomsList(*args))

    def Freedoms(self, *args) -> "opencascade::handle< StepFEA_HArray1OfDegreeOfFreedom >":
        r"""
        Returns field freedoms.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfDegreeOfFreedom>

        """
        return _StepFEA.StepFEA_FreedomsList_Freedoms(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aFreedoms: StepFEA_HArray1OfDegreeOfFreedom

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FreedomsList_Init(self, *args)

    def SetFreedoms(self, *args) -> "void":
        r"""
        Set field freedoms.

        Parameters
        ----------
        Freedoms: StepFEA_HArray1OfDegreeOfFreedom

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FreedomsList_SetFreedoms(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FreedomsList_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FreedomsList

# Register StepFEA_FreedomsList in _StepFEA:
_StepFEA.StepFEA_FreedomsList_swigregister(StepFEA_FreedomsList)

class StepFEA_NodeDefinition(OCC.Core.StepRepr.StepRepr_ShapeAspect):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_NodeDefinition_swiginit(self, _StepFEA.new_StepFEA_NodeDefinition(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_NodeDefinition_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_NodeDefinition

# Register StepFEA_NodeDefinition in _StepFEA:
_StepFEA.StepFEA_NodeDefinition_swigregister(StepFEA_NodeDefinition)

class StepFEA_NodeRepresentation(OCC.Core.StepRepr.StepRepr_Representation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_NodeRepresentation_swiginit(self, _StepFEA.new_StepFEA_NodeRepresentation(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentation_Name: TCollection_HAsciiString
        aRepresentation_Items: StepRepr_HArray1OfRepresentationItem
        aRepresentation_ContextOfItems: StepRepr_RepresentationContext
        aModelRef: StepFEA_FeaModel

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_NodeRepresentation_Init(self, *args)

    def ModelRef(self, *args) -> "opencascade::handle< StepFEA_FeaModel >":
        r"""
        Returns field modelref.

        Returns
        -------
        opencascade::handle<StepFEA_FeaModel>

        """
        return _StepFEA.StepFEA_NodeRepresentation_ModelRef(self, *args)

    def SetModelRef(self, *args) -> "void":
        r"""
        Set field modelref.

        Parameters
        ----------
        ModelRef: StepFEA_FeaModel

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_NodeRepresentation_SetModelRef(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_NodeRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_NodeRepresentation

# Register StepFEA_NodeRepresentation in _StepFEA:
_StepFEA.StepFEA_NodeRepresentation_swigregister(StepFEA_NodeRepresentation)

class StepFEA_NodeSet(OCC.Core.StepGeom.StepGeom_GeometricRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_NodeSet_swiginit(self, _StepFEA.new_StepFEA_NodeSet(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aNodes: StepFEA_HArray1OfNodeRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_NodeSet_Init(self, *args)

    def Nodes(self, *args) -> "opencascade::handle< StepFEA_HArray1OfNodeRepresentation >":
        r"""
        Returns field nodes.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfNodeRepresentation>

        """
        return _StepFEA.StepFEA_NodeSet_Nodes(self, *args)

    def SetNodes(self, *args) -> "void":
        r"""
        Set field nodes.

        Parameters
        ----------
        Nodes: StepFEA_HArray1OfNodeRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_NodeSet_SetNodes(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_NodeSet_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_NodeSet

# Register StepFEA_NodeSet in _StepFEA:
_StepFEA.StepFEA_NodeSet_swigregister(StepFEA_NodeSet)

class StepFEA_SymmetricTensor22d(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_SymmetricTensor22d_swiginit(self, _StepFEA.new_StepFEA_SymmetricTensor22d(*args))

    def AnisotropicSymmetricTensor22d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as anisotropicsymmetrictensor22d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor22d_AnisotropicSymmetricTensor22d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_SymmetricTensor22d

# Register StepFEA_SymmetricTensor22d in _StepFEA:
_StepFEA.StepFEA_SymmetricTensor22d_swigregister(StepFEA_SymmetricTensor22d)

class StepFEA_SymmetricTensor23d(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_SymmetricTensor23d_swiginit(self, _StepFEA.new_StepFEA_SymmetricTensor23d(*args))

    def AnisotropicSymmetricTensor23d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as anisotropicsymmetrictensor23d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor23d_AnisotropicSymmetricTensor23d(self, *args)

    def IsotropicSymmetricTensor23d(self, *args) -> "Standard_Real":
        r"""
        Returns value as isotropicsymmetrictensor23d (or null if another type).

        Returns
        -------
        float

        """
        return _StepFEA.StepFEA_SymmetricTensor23d_IsotropicSymmetricTensor23d(self, *args)

    def OrthotropicSymmetricTensor23d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as orthotropicsymmetrictensor23d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor23d_OrthotropicSymmetricTensor23d(self, *args)

    def SetAnisotropicSymmetricTensor23d(self, *args) -> "void":
        r"""
        Set value for anisotropicsymmetrictensor23d.

        Parameters
        ----------
        aVal: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_SymmetricTensor23d_SetAnisotropicSymmetricTensor23d(self, *args)

    def SetIsotropicSymmetricTensor23d(self, *args) -> "void":
        r"""
        Set value for isotropicsymmetrictensor23d.

        Parameters
        ----------
        aVal: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_SymmetricTensor23d_SetIsotropicSymmetricTensor23d(self, *args)

    def SetOrthotropicSymmetricTensor23d(self, *args) -> "void":
        r"""
        Set value for orthotropicsymmetrictensor23d.

        Parameters
        ----------
        aVal: TColStd_HArray1OfReal

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_SymmetricTensor23d_SetOrthotropicSymmetricTensor23d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_SymmetricTensor23d

# Register StepFEA_SymmetricTensor23d in _StepFEA:
_StepFEA.StepFEA_SymmetricTensor23d_swigregister(StepFEA_SymmetricTensor23d)

class StepFEA_SymmetricTensor23dMember(OCC.Core.StepData.StepData_SelectArrReal):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_SymmetricTensor23dMember_swiginit(self, _StepFEA.new_StepFEA_SymmetricTensor23dMember(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_SymmetricTensor23dMember_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_SymmetricTensor23dMember

# Register StepFEA_SymmetricTensor23dMember in _StepFEA:
_StepFEA.StepFEA_SymmetricTensor23dMember_swigregister(StepFEA_SymmetricTensor23dMember)

class StepFEA_SymmetricTensor42d(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_SymmetricTensor42d_swiginit(self, _StepFEA.new_StepFEA_SymmetricTensor42d(*args))

    def AnisotropicSymmetricTensor42d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as anisotropicsymmetrictensor42d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor42d_AnisotropicSymmetricTensor42d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_SymmetricTensor42d

# Register StepFEA_SymmetricTensor42d in _StepFEA:
_StepFEA.StepFEA_SymmetricTensor42d_swigregister(StepFEA_SymmetricTensor42d)

class StepFEA_SymmetricTensor43d(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_SymmetricTensor43d_swiginit(self, _StepFEA.new_StepFEA_SymmetricTensor43d(*args))

    def AnisotropicSymmetricTensor43d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as anisotropicsymmetrictensor43d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor43d_AnisotropicSymmetricTensor43d(self, *args)

    def FeaColumnNormalisedMonoclinicSymmetricTensor43d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as feacolumnnormalisedmonoclinicsymmetrictensor43d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor43d_FeaColumnNormalisedMonoclinicSymmetricTensor43d(self, *args)

    def FeaColumnNormalisedOrthotropicSymmetricTensor43d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as feacolumnnormalisedorthotropicsymmetrictensor43d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor43d_FeaColumnNormalisedOrthotropicSymmetricTensor43d(self, *args)

    def FeaIsoOrthotropicSymmetricTensor43d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as feaisoorthotropicsymmetrictensor43d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor43d_FeaIsoOrthotropicSymmetricTensor43d(self, *args)

    def FeaIsotropicSymmetricTensor43d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as feaisotropicsymmetrictensor43d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor43d_FeaIsotropicSymmetricTensor43d(self, *args)

    def FeaTransverseIsotropicSymmetricTensor43d(self, *args) -> "opencascade::handle< TColStd_HArray1OfReal >":
        r"""
        Returns value as featransverseisotropicsymmetrictensor43d (or null if another type).

        Returns
        -------
        opencascade::handle<TColStd_HArray1OfReal>

        """
        return _StepFEA.StepFEA_SymmetricTensor43d_FeaTransverseIsotropicSymmetricTensor43d(self, *args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def SetFeaIsotropicSymmetricTensor43d(self):
    	pass

    __swig_destroy__ = _StepFEA.delete_StepFEA_SymmetricTensor43d

# Register StepFEA_SymmetricTensor43d in _StepFEA:
_StepFEA.StepFEA_SymmetricTensor43d_swigregister(StepFEA_SymmetricTensor43d)

class StepFEA_SymmetricTensor43dMember(OCC.Core.StepData.StepData_SelectArrReal):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_SymmetricTensor43dMember_swiginit(self, _StepFEA.new_StepFEA_SymmetricTensor43dMember(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_SymmetricTensor43dMember_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_SymmetricTensor43dMember

# Register StepFEA_SymmetricTensor43dMember in _StepFEA:
_StepFEA.StepFEA_SymmetricTensor43dMember_swigregister(StepFEA_SymmetricTensor43dMember)

class StepFEA_AlignedCurve3dElementCoordinateSystem(StepFEA_FeaRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_AlignedCurve3dElementCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_AlignedCurve3dElementCoordinateSystem(*args))

    def CoordinateSystem(self, *args) -> "opencascade::handle< StepFEA_FeaAxis2Placement3d >":
        r"""
        Returns field coordinatesystem.

        Returns
        -------
        opencascade::handle<StepFEA_FeaAxis2Placement3d>

        """
        return _StepFEA.StepFEA_AlignedCurve3dElementCoordinateSystem_CoordinateSystem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aCoordinateSystem: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_AlignedCurve3dElementCoordinateSystem_Init(self, *args)

    def SetCoordinateSystem(self, *args) -> "void":
        r"""
        Set field coordinatesystem.

        Parameters
        ----------
        CoordinateSystem: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_AlignedCurve3dElementCoordinateSystem_SetCoordinateSystem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_AlignedCurve3dElementCoordinateSystem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_AlignedCurve3dElementCoordinateSystem

# Register StepFEA_AlignedCurve3dElementCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_AlignedCurve3dElementCoordinateSystem_swigregister(StepFEA_AlignedCurve3dElementCoordinateSystem)

class StepFEA_AlignedSurface3dElementCoordinateSystem(StepFEA_FeaRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_AlignedSurface3dElementCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_AlignedSurface3dElementCoordinateSystem(*args))

    def CoordinateSystem(self, *args) -> "opencascade::handle< StepFEA_FeaAxis2Placement3d >":
        r"""
        Returns field coordinatesystem.

        Returns
        -------
        opencascade::handle<StepFEA_FeaAxis2Placement3d>

        """
        return _StepFEA.StepFEA_AlignedSurface3dElementCoordinateSystem_CoordinateSystem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aCoordinateSystem: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_AlignedSurface3dElementCoordinateSystem_Init(self, *args)

    def SetCoordinateSystem(self, *args) -> "void":
        r"""
        Set field coordinatesystem.

        Parameters
        ----------
        CoordinateSystem: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_AlignedSurface3dElementCoordinateSystem_SetCoordinateSystem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_AlignedSurface3dElementCoordinateSystem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_AlignedSurface3dElementCoordinateSystem

# Register StepFEA_AlignedSurface3dElementCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_AlignedSurface3dElementCoordinateSystem_swigregister(StepFEA_AlignedSurface3dElementCoordinateSystem)

class StepFEA_ArbitraryVolume3dElementCoordinateSystem(StepFEA_FeaRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ArbitraryVolume3dElementCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_ArbitraryVolume3dElementCoordinateSystem(*args))

    def CoordinateSystem(self, *args) -> "opencascade::handle< StepFEA_FeaAxis2Placement3d >":
        r"""
        Returns field coordinatesystem.

        Returns
        -------
        opencascade::handle<StepFEA_FeaAxis2Placement3d>

        """
        return _StepFEA.StepFEA_ArbitraryVolume3dElementCoordinateSystem_CoordinateSystem(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aCoordinateSystem: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ArbitraryVolume3dElementCoordinateSystem_Init(self, *args)

    def SetCoordinateSystem(self, *args) -> "void":
        r"""
        Set field coordinatesystem.

        Parameters
        ----------
        CoordinateSystem: StepFEA_FeaAxis2Placement3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ArbitraryVolume3dElementCoordinateSystem_SetCoordinateSystem(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ArbitraryVolume3dElementCoordinateSystem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ArbitraryVolume3dElementCoordinateSystem

# Register StepFEA_ArbitraryVolume3dElementCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_ArbitraryVolume3dElementCoordinateSystem_swigregister(StepFEA_ArbitraryVolume3dElementCoordinateSystem)

class StepFEA_ConstantSurface3dElementCoordinateSystem(StepFEA_FeaRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ConstantSurface3dElementCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_ConstantSurface3dElementCoordinateSystem(*args))

    def Angle(self, *args) -> "Standard_Real":
        r"""
        Returns field angle.

        Returns
        -------
        float

        """
        return _StepFEA.StepFEA_ConstantSurface3dElementCoordinateSystem_Angle(self, *args)

    def Axis(self, *args) -> "Standard_Integer":
        r"""
        Returns field axis.

        Returns
        -------
        int

        """
        return _StepFEA.StepFEA_ConstantSurface3dElementCoordinateSystem_Axis(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aAxis: int
        aAngle: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ConstantSurface3dElementCoordinateSystem_Init(self, *args)

    def SetAngle(self, *args) -> "void":
        r"""
        Set field angle.

        Parameters
        ----------
        Angle: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ConstantSurface3dElementCoordinateSystem_SetAngle(self, *args)

    def SetAxis(self, *args) -> "void":
        r"""
        Set field axis.

        Parameters
        ----------
        Axis: int

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ConstantSurface3dElementCoordinateSystem_SetAxis(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ConstantSurface3dElementCoordinateSystem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ConstantSurface3dElementCoordinateSystem

# Register StepFEA_ConstantSurface3dElementCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_ConstantSurface3dElementCoordinateSystem_swigregister(StepFEA_ConstantSurface3dElementCoordinateSystem)

class StepFEA_Curve3dElementRepresentation(StepFEA_ElementRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_Curve3dElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_Curve3dElementRepresentation(*args))

    def ElementDescriptor(self, *args) -> "opencascade::handle< StepElement_Curve3dElementDescriptor >":
        r"""
        Returns field elementdescriptor.

        Returns
        -------
        opencascade::handle<StepElement_Curve3dElementDescriptor>

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_ElementDescriptor(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentation_Name: TCollection_HAsciiString
        aRepresentation_Items: StepRepr_HArray1OfRepresentationItem
        aRepresentation_ContextOfItems: StepRepr_RepresentationContext
        aElementRepresentation_NodeList: StepFEA_HArray1OfNodeRepresentation
        aModelRef: StepFEA_FeaModel3d
        aElementDescriptor: StepElement_Curve3dElementDescriptor
        aProperty: StepFEA_Curve3dElementProperty
        aMaterial: StepElement_ElementMaterial

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_Init(self, *args)

    def Material(self, *args) -> "opencascade::handle< StepElement_ElementMaterial >":
        r"""
        Returns field material.

        Returns
        -------
        opencascade::handle<StepElement_ElementMaterial>

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_Material(self, *args)

    def ModelRef(self, *args) -> "opencascade::handle< StepFEA_FeaModel3d >":
        r"""
        Returns field modelref.

        Returns
        -------
        opencascade::handle<StepFEA_FeaModel3d>

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_ModelRef(self, *args)

    def Property(self, *args) -> "opencascade::handle< StepFEA_Curve3dElementProperty >":
        r"""
        Returns field property.

        Returns
        -------
        opencascade::handle<StepFEA_Curve3dElementProperty>

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_Property(self, *args)

    def SetElementDescriptor(self, *args) -> "void":
        r"""
        Set field elementdescriptor.

        Parameters
        ----------
        ElementDescriptor: StepElement_Curve3dElementDescriptor

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_SetElementDescriptor(self, *args)

    def SetMaterial(self, *args) -> "void":
        r"""
        Set field material.

        Parameters
        ----------
        Material: StepElement_ElementMaterial

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_SetMaterial(self, *args)

    def SetModelRef(self, *args) -> "void":
        r"""
        Set field modelref.

        Parameters
        ----------
        ModelRef: StepFEA_FeaModel3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_SetModelRef(self, *args)

    def SetProperty(self, *args) -> "void":
        r"""
        Set field property.

        Parameters
        ----------
        Property: StepFEA_Curve3dElementProperty

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Curve3dElementRepresentation_SetProperty(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_Curve3dElementRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_Curve3dElementRepresentation

# Register StepFEA_Curve3dElementRepresentation in _StepFEA:
_StepFEA.StepFEA_Curve3dElementRepresentation_swigregister(StepFEA_Curve3dElementRepresentation)

class StepFEA_CurveElementIntervalConstant(StepFEA_CurveElementInterval):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_CurveElementIntervalConstant_swiginit(self, _StepFEA.new_StepFEA_CurveElementIntervalConstant(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aCurveElementInterval_FinishPosition: StepFEA_CurveElementLocation
        aCurveElementInterval_EuAngles: StepBasic_EulerAngles
        aSection: StepElement_CurveElementSectionDefinition

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementIntervalConstant_Init(self, *args)

    def Section(self, *args) -> "opencascade::handle< StepElement_CurveElementSectionDefinition >":
        r"""
        Returns field section.

        Returns
        -------
        opencascade::handle<StepElement_CurveElementSectionDefinition>

        """
        return _StepFEA.StepFEA_CurveElementIntervalConstant_Section(self, *args)

    def SetSection(self, *args) -> "void":
        r"""
        Set field section.

        Parameters
        ----------
        Section: StepElement_CurveElementSectionDefinition

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementIntervalConstant_SetSection(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_CurveElementIntervalConstant_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_CurveElementIntervalConstant

# Register StepFEA_CurveElementIntervalConstant in _StepFEA:
_StepFEA.StepFEA_CurveElementIntervalConstant_swigregister(StepFEA_CurveElementIntervalConstant)

class StepFEA_CurveElementIntervalLinearlyVarying(StepFEA_CurveElementInterval):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_CurveElementIntervalLinearlyVarying_swiginit(self, _StepFEA.new_StepFEA_CurveElementIntervalLinearlyVarying(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aCurveElementInterval_FinishPosition: StepFEA_CurveElementLocation
        aCurveElementInterval_EuAngles: StepBasic_EulerAngles
        aSections: StepElement_HArray1OfCurveElementSectionDefinition

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementIntervalLinearlyVarying_Init(self, *args)

    def Sections(self, *args) -> "opencascade::handle< StepElement_HArray1OfCurveElementSectionDefinition >":
        r"""
        Returns field sections.

        Returns
        -------
        opencascade::handle<StepElement_HArray1OfCurveElementSectionDefinition>

        """
        return _StepFEA.StepFEA_CurveElementIntervalLinearlyVarying_Sections(self, *args)

    def SetSections(self, *args) -> "void":
        r"""
        Set field sections.

        Parameters
        ----------
        Sections: StepElement_HArray1OfCurveElementSectionDefinition

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_CurveElementIntervalLinearlyVarying_SetSections(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_CurveElementIntervalLinearlyVarying_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_CurveElementIntervalLinearlyVarying

# Register StepFEA_CurveElementIntervalLinearlyVarying in _StepFEA:
_StepFEA.StepFEA_CurveElementIntervalLinearlyVarying_swigregister(StepFEA_CurveElementIntervalLinearlyVarying)

class StepFEA_DummyNode(StepFEA_NodeRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_DummyNode_swiginit(self, _StepFEA.new_StepFEA_DummyNode(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_DummyNode_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_DummyNode

# Register StepFEA_DummyNode in _StepFEA:
_StepFEA.StepFEA_DummyNode_swigregister(StepFEA_DummyNode)

class StepFEA_ElementGroup(StepFEA_FeaGroup):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ElementGroup_swiginit(self, _StepFEA.new_StepFEA_ElementGroup(*args))

    def Elements(self, *args) -> "opencascade::handle< StepFEA_HArray1OfElementRepresentation >":
        r"""
        Returns field elements.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfElementRepresentation>

        """
        return _StepFEA.StepFEA_ElementGroup_Elements(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aGroup_Name: TCollection_HAsciiString
        aGroup_Description: TCollection_HAsciiString
        aFeaGroup_ModelRef: StepFEA_FeaModel
        aElements: StepFEA_HArray1OfElementRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementGroup_Init(self, *args)

    def SetElements(self, *args) -> "void":
        r"""
        Set field elements.

        Parameters
        ----------
        Elements: StepFEA_HArray1OfElementRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ElementGroup_SetElements(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ElementGroup_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ElementGroup

# Register StepFEA_ElementGroup in _StepFEA:
_StepFEA.StepFEA_ElementGroup_swigregister(StepFEA_ElementGroup)

class StepFEA_FeaAreaDensity(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaAreaDensity_swiginit(self, _StepFEA.new_StepFEA_FeaAreaDensity(*args))

    def FeaConstant(self, *args) -> "Standard_Real":
        r"""
        Returns field feaconstant.

        Returns
        -------
        float

        """
        return _StepFEA.StepFEA_FeaAreaDensity_FeaConstant(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstant: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaAreaDensity_Init(self, *args)

    def SetFeaConstant(self, *args) -> "void":
        r"""
        Set field feaconstant.

        Parameters
        ----------
        FeaConstant: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaAreaDensity_SetFeaConstant(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaAreaDensity_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaAreaDensity

# Register StepFEA_FeaAreaDensity in _StepFEA:
_StepFEA.StepFEA_FeaAreaDensity_swigregister(StepFEA_FeaAreaDensity)

class StepFEA_FeaLinearElasticity(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaLinearElasticity_swiginit(self, _StepFEA.new_StepFEA_FeaLinearElasticity(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor43d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor43d

        """
        return _StepFEA.StepFEA_FeaLinearElasticity_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor43d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaLinearElasticity_Init(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor43d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaLinearElasticity_SetFeaConstants(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaLinearElasticity_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaLinearElasticity

# Register StepFEA_FeaLinearElasticity in _StepFEA:
_StepFEA.StepFEA_FeaLinearElasticity_swigregister(StepFEA_FeaLinearElasticity)

class StepFEA_FeaMassDensity(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaMassDensity_swiginit(self, _StepFEA.new_StepFEA_FeaMassDensity(*args))

    def FeaConstant(self, *args) -> "Standard_Real":
        r"""
        Returns field feaconstant.

        Returns
        -------
        float

        """
        return _StepFEA.StepFEA_FeaMassDensity_FeaConstant(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstant: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaMassDensity_Init(self, *args)

    def SetFeaConstant(self, *args) -> "void":
        r"""
        Set field feaconstant.

        Parameters
        ----------
        FeaConstant: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaMassDensity_SetFeaConstant(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaMassDensity_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaMassDensity

# Register StepFEA_FeaMassDensity in _StepFEA:
_StepFEA.StepFEA_FeaMassDensity_swigregister(StepFEA_FeaMassDensity)

class StepFEA_FeaModel3d(StepFEA_FeaModel):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaModel3d_swiginit(self, _StepFEA.new_StepFEA_FeaModel3d(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaModel3d_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaModel3d

# Register StepFEA_FeaModel3d in _StepFEA:
_StepFEA.StepFEA_FeaModel3d_swigregister(StepFEA_FeaModel3d)

class StepFEA_FeaMoistureAbsorption(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaMoistureAbsorption_swiginit(self, _StepFEA.new_StepFEA_FeaMoistureAbsorption(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor23d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor23d

        """
        return _StepFEA.StepFEA_FeaMoistureAbsorption_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor23d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaMoistureAbsorption_Init(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor23d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaMoistureAbsorption_SetFeaConstants(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaMoistureAbsorption_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaMoistureAbsorption

# Register StepFEA_FeaMoistureAbsorption in _StepFEA:
_StepFEA.StepFEA_FeaMoistureAbsorption_swigregister(StepFEA_FeaMoistureAbsorption)

class StepFEA_FeaSecantCoefficientOfLinearThermalExpansion(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_swiginit(self, _StepFEA.new_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor23d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor23d

        """
        return _StepFEA.StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor23d
        aReferenceTemperature: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_Init(self, *args)

    def ReferenceTemperature(self, *args) -> "Standard_Real":
        r"""
        Returns field referencetemperature.

        Returns
        -------
        float

        """
        return _StepFEA.StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_ReferenceTemperature(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor23d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_SetFeaConstants(self, *args)

    def SetReferenceTemperature(self, *args) -> "void":
        r"""
        Set field referencetemperature.

        Parameters
        ----------
        ReferenceTemperature: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_SetReferenceTemperature(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaSecantCoefficientOfLinearThermalExpansion

# Register StepFEA_FeaSecantCoefficientOfLinearThermalExpansion in _StepFEA:
_StepFEA.StepFEA_FeaSecantCoefficientOfLinearThermalExpansion_swigregister(StepFEA_FeaSecantCoefficientOfLinearThermalExpansion)

class StepFEA_FeaShellBendingStiffness(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaShellBendingStiffness_swiginit(self, _StepFEA.new_StepFEA_FeaShellBendingStiffness(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor42d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor42d

        """
        return _StepFEA.StepFEA_FeaShellBendingStiffness_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor42d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellBendingStiffness_Init(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor42d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellBendingStiffness_SetFeaConstants(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaShellBendingStiffness_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaShellBendingStiffness

# Register StepFEA_FeaShellBendingStiffness in _StepFEA:
_StepFEA.StepFEA_FeaShellBendingStiffness_swigregister(StepFEA_FeaShellBendingStiffness)

class StepFEA_FeaShellMembraneBendingCouplingStiffness(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaShellMembraneBendingCouplingStiffness_swiginit(self, _StepFEA.new_StepFEA_FeaShellMembraneBendingCouplingStiffness(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor42d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor42d

        """
        return _StepFEA.StepFEA_FeaShellMembraneBendingCouplingStiffness_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor42d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellMembraneBendingCouplingStiffness_Init(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor42d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellMembraneBendingCouplingStiffness_SetFeaConstants(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaShellMembraneBendingCouplingStiffness_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaShellMembraneBendingCouplingStiffness

# Register StepFEA_FeaShellMembraneBendingCouplingStiffness in _StepFEA:
_StepFEA.StepFEA_FeaShellMembraneBendingCouplingStiffness_swigregister(StepFEA_FeaShellMembraneBendingCouplingStiffness)

class StepFEA_FeaShellMembraneStiffness(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaShellMembraneStiffness_swiginit(self, _StepFEA.new_StepFEA_FeaShellMembraneStiffness(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor42d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor42d

        """
        return _StepFEA.StepFEA_FeaShellMembraneStiffness_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor42d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellMembraneStiffness_Init(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor42d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellMembraneStiffness_SetFeaConstants(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaShellMembraneStiffness_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaShellMembraneStiffness

# Register StepFEA_FeaShellMembraneStiffness in _StepFEA:
_StepFEA.StepFEA_FeaShellMembraneStiffness_swigregister(StepFEA_FeaShellMembraneStiffness)

class StepFEA_FeaShellShearStiffness(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaShellShearStiffness_swiginit(self, _StepFEA.new_StepFEA_FeaShellShearStiffness(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor22d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor22d

        """
        return _StepFEA.StepFEA_FeaShellShearStiffness_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor22d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellShearStiffness_Init(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor22d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaShellShearStiffness_SetFeaConstants(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaShellShearStiffness_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaShellShearStiffness

# Register StepFEA_FeaShellShearStiffness in _StepFEA:
_StepFEA.StepFEA_FeaShellShearStiffness_swigregister(StepFEA_FeaShellShearStiffness)

class StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion(StepFEA_FeaMaterialPropertyRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_swiginit(self, _StepFEA.new_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion(*args))

    def FeaConstants(self, *args) -> "StepFEA_SymmetricTensor23d":
        r"""
        Returns field feaconstants.

        Returns
        -------
        StepFEA_SymmetricTensor23d

        """
        return _StepFEA.StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_FeaConstants(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aFeaConstants: StepFEA_SymmetricTensor23d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_Init(self, *args)

    def SetFeaConstants(self, *args) -> "void":
        r"""
        Set field feaconstants.

        Parameters
        ----------
        FeaConstants: StepFEA_SymmetricTensor23d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_SetFeaConstants(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion

# Register StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion in _StepFEA:
_StepFEA.StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion_swigregister(StepFEA_FeaTangentialCoefficientOfLinearThermalExpansion)

class StepFEA_GeometricNode(StepFEA_NodeRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_GeometricNode_swiginit(self, _StepFEA.new_StepFEA_GeometricNode(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_GeometricNode_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_GeometricNode

# Register StepFEA_GeometricNode in _StepFEA:
_StepFEA.StepFEA_GeometricNode_swigregister(StepFEA_GeometricNode)

class StepFEA_Node(StepFEA_NodeRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_Node_swiginit(self, _StepFEA.new_StepFEA_Node(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_Node_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_Node

# Register StepFEA_Node in _StepFEA:
_StepFEA.StepFEA_Node_swigregister(StepFEA_Node)

class StepFEA_NodeGroup(StepFEA_FeaGroup):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_NodeGroup_swiginit(self, _StepFEA.new_StepFEA_NodeGroup(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aGroup_Name: TCollection_HAsciiString
        aGroup_Description: TCollection_HAsciiString
        aFeaGroup_ModelRef: StepFEA_FeaModel
        aNodes: StepFEA_HArray1OfNodeRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_NodeGroup_Init(self, *args)

    def Nodes(self, *args) -> "opencascade::handle< StepFEA_HArray1OfNodeRepresentation >":
        r"""
        Returns field nodes.

        Returns
        -------
        opencascade::handle<StepFEA_HArray1OfNodeRepresentation>

        """
        return _StepFEA.StepFEA_NodeGroup_Nodes(self, *args)

    def SetNodes(self, *args) -> "void":
        r"""
        Set field nodes.

        Parameters
        ----------
        Nodes: StepFEA_HArray1OfNodeRepresentation

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_NodeGroup_SetNodes(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_NodeGroup_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_NodeGroup

# Register StepFEA_NodeGroup in _StepFEA:
_StepFEA.StepFEA_NodeGroup_swigregister(StepFEA_NodeGroup)

class StepFEA_ParametricCurve3dElementCoordinateDirection(StepFEA_FeaRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ParametricCurve3dElementCoordinateDirection_swiginit(self, _StepFEA.new_StepFEA_ParametricCurve3dElementCoordinateDirection(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aOrientation: StepGeom_Direction

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ParametricCurve3dElementCoordinateDirection_Init(self, *args)

    def Orientation(self, *args) -> "opencascade::handle< StepGeom_Direction >":
        r"""
        Returns field orientation.

        Returns
        -------
        opencascade::handle<StepGeom_Direction>

        """
        return _StepFEA.StepFEA_ParametricCurve3dElementCoordinateDirection_Orientation(self, *args)

    def SetOrientation(self, *args) -> "void":
        r"""
        Set field orientation.

        Parameters
        ----------
        Orientation: StepGeom_Direction

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ParametricCurve3dElementCoordinateDirection_SetOrientation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ParametricCurve3dElementCoordinateDirection_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ParametricCurve3dElementCoordinateDirection

# Register StepFEA_ParametricCurve3dElementCoordinateDirection in _StepFEA:
_StepFEA.StepFEA_ParametricCurve3dElementCoordinateDirection_swigregister(StepFEA_ParametricCurve3dElementCoordinateDirection)

class StepFEA_ParametricCurve3dElementCoordinateSystem(StepFEA_FeaRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ParametricCurve3dElementCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_ParametricCurve3dElementCoordinateSystem(*args))

    def Direction(self, *args) -> "opencascade::handle< StepFEA_ParametricCurve3dElementCoordinateDirection >":
        r"""
        Returns field direction.

        Returns
        -------
        opencascade::handle<StepFEA_ParametricCurve3dElementCoordinateDirection>

        """
        return _StepFEA.StepFEA_ParametricCurve3dElementCoordinateSystem_Direction(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aDirection: StepFEA_ParametricCurve3dElementCoordinateDirection

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ParametricCurve3dElementCoordinateSystem_Init(self, *args)

    def SetDirection(self, *args) -> "void":
        r"""
        Set field direction.

        Parameters
        ----------
        Direction: StepFEA_ParametricCurve3dElementCoordinateDirection

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ParametricCurve3dElementCoordinateSystem_SetDirection(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ParametricCurve3dElementCoordinateSystem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ParametricCurve3dElementCoordinateSystem

# Register StepFEA_ParametricCurve3dElementCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_ParametricCurve3dElementCoordinateSystem_swigregister(StepFEA_ParametricCurve3dElementCoordinateSystem)

class StepFEA_ParametricSurface3dElementCoordinateSystem(StepFEA_FeaRepresentationItem):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_ParametricSurface3dElementCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_ParametricSurface3dElementCoordinateSystem(*args))

    def Angle(self, *args) -> "Standard_Real":
        r"""
        Returns field angle.

        Returns
        -------
        float

        """
        return _StepFEA.StepFEA_ParametricSurface3dElementCoordinateSystem_Angle(self, *args)

    def Axis(self, *args) -> "Standard_Integer":
        r"""
        Returns field axis.

        Returns
        -------
        int

        """
        return _StepFEA.StepFEA_ParametricSurface3dElementCoordinateSystem_Axis(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentationItem_Name: TCollection_HAsciiString
        aAxis: int
        aAngle: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ParametricSurface3dElementCoordinateSystem_Init(self, *args)

    def SetAngle(self, *args) -> "void":
        r"""
        Set field angle.

        Parameters
        ----------
        Angle: float

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ParametricSurface3dElementCoordinateSystem_SetAngle(self, *args)

    def SetAxis(self, *args) -> "void":
        r"""
        Set field axis.

        Parameters
        ----------
        Axis: int

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_ParametricSurface3dElementCoordinateSystem_SetAxis(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_ParametricSurface3dElementCoordinateSystem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_ParametricSurface3dElementCoordinateSystem

# Register StepFEA_ParametricSurface3dElementCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_ParametricSurface3dElementCoordinateSystem_swigregister(StepFEA_ParametricSurface3dElementCoordinateSystem)

class StepFEA_Surface3dElementRepresentation(StepFEA_ElementRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_Surface3dElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_Surface3dElementRepresentation(*args))

    def ElementDescriptor(self, *args) -> "opencascade::handle< StepElement_Surface3dElementDescriptor >":
        r"""
        Returns field elementdescriptor.

        Returns
        -------
        opencascade::handle<StepElement_Surface3dElementDescriptor>

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_ElementDescriptor(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentation_Name: TCollection_HAsciiString
        aRepresentation_Items: StepRepr_HArray1OfRepresentationItem
        aRepresentation_ContextOfItems: StepRepr_RepresentationContext
        aElementRepresentation_NodeList: StepFEA_HArray1OfNodeRepresentation
        aModelRef: StepFEA_FeaModel3d
        aElementDescriptor: StepElement_Surface3dElementDescriptor
        aProperty: StepElement_SurfaceElementProperty
        aMaterial: StepElement_ElementMaterial

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_Init(self, *args)

    def Material(self, *args) -> "opencascade::handle< StepElement_ElementMaterial >":
        r"""
        Returns field material.

        Returns
        -------
        opencascade::handle<StepElement_ElementMaterial>

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_Material(self, *args)

    def ModelRef(self, *args) -> "opencascade::handle< StepFEA_FeaModel3d >":
        r"""
        Returns field modelref.

        Returns
        -------
        opencascade::handle<StepFEA_FeaModel3d>

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_ModelRef(self, *args)

    def Property(self, *args) -> "opencascade::handle< StepElement_SurfaceElementProperty >":
        r"""
        Returns field property.

        Returns
        -------
        opencascade::handle<StepElement_SurfaceElementProperty>

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_Property(self, *args)

    def SetElementDescriptor(self, *args) -> "void":
        r"""
        Set field elementdescriptor.

        Parameters
        ----------
        ElementDescriptor: StepElement_Surface3dElementDescriptor

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_SetElementDescriptor(self, *args)

    def SetMaterial(self, *args) -> "void":
        r"""
        Set field material.

        Parameters
        ----------
        Material: StepElement_ElementMaterial

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_SetMaterial(self, *args)

    def SetModelRef(self, *args) -> "void":
        r"""
        Set field modelref.

        Parameters
        ----------
        ModelRef: StepFEA_FeaModel3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_SetModelRef(self, *args)

    def SetProperty(self, *args) -> "void":
        r"""
        Set field property.

        Parameters
        ----------
        Property: StepElement_SurfaceElementProperty

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Surface3dElementRepresentation_SetProperty(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_Surface3dElementRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_Surface3dElementRepresentation

# Register StepFEA_Surface3dElementRepresentation in _StepFEA:
_StepFEA.StepFEA_Surface3dElementRepresentation_swigregister(StepFEA_Surface3dElementRepresentation)

class StepFEA_Volume3dElementRepresentation(StepFEA_ElementRepresentation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_Volume3dElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_Volume3dElementRepresentation(*args))

    def ElementDescriptor(self, *args) -> "opencascade::handle< StepElement_Volume3dElementDescriptor >":
        r"""
        Returns field elementdescriptor.

        Returns
        -------
        opencascade::handle<StepElement_Volume3dElementDescriptor>

        """
        return _StepFEA.StepFEA_Volume3dElementRepresentation_ElementDescriptor(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aRepresentation_Name: TCollection_HAsciiString
        aRepresentation_Items: StepRepr_HArray1OfRepresentationItem
        aRepresentation_ContextOfItems: StepRepr_RepresentationContext
        aElementRepresentation_NodeList: StepFEA_HArray1OfNodeRepresentation
        aModelRef: StepFEA_FeaModel3d
        aElementDescriptor: StepElement_Volume3dElementDescriptor
        aMaterial: StepElement_ElementMaterial

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Volume3dElementRepresentation_Init(self, *args)

    def Material(self, *args) -> "opencascade::handle< StepElement_ElementMaterial >":
        r"""
        Returns field material.

        Returns
        -------
        opencascade::handle<StepElement_ElementMaterial>

        """
        return _StepFEA.StepFEA_Volume3dElementRepresentation_Material(self, *args)

    def ModelRef(self, *args) -> "opencascade::handle< StepFEA_FeaModel3d >":
        r"""
        Returns field modelref.

        Returns
        -------
        opencascade::handle<StepFEA_FeaModel3d>

        """
        return _StepFEA.StepFEA_Volume3dElementRepresentation_ModelRef(self, *args)

    def SetElementDescriptor(self, *args) -> "void":
        r"""
        Set field elementdescriptor.

        Parameters
        ----------
        ElementDescriptor: StepElement_Volume3dElementDescriptor

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Volume3dElementRepresentation_SetElementDescriptor(self, *args)

    def SetMaterial(self, *args) -> "void":
        r"""
        Set field material.

        Parameters
        ----------
        Material: StepElement_ElementMaterial

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Volume3dElementRepresentation_SetMaterial(self, *args)

    def SetModelRef(self, *args) -> "void":
        r"""
        Set field modelref.

        Parameters
        ----------
        ModelRef: StepFEA_FeaModel3d

        Returns
        -------
        None

        """
        return _StepFEA.StepFEA_Volume3dElementRepresentation_SetModelRef(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_Volume3dElementRepresentation_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_Volume3dElementRepresentation

# Register StepFEA_Volume3dElementRepresentation in _StepFEA:
_StepFEA.StepFEA_Volume3dElementRepresentation_swigregister(StepFEA_Volume3dElementRepresentation)

class StepFEA_NodeWithSolutionCoordinateSystem(StepFEA_Node):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_NodeWithSolutionCoordinateSystem_swiginit(self, _StepFEA.new_StepFEA_NodeWithSolutionCoordinateSystem(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_NodeWithSolutionCoordinateSystem_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_NodeWithSolutionCoordinateSystem

# Register StepFEA_NodeWithSolutionCoordinateSystem in _StepFEA:
_StepFEA.StepFEA_NodeWithSolutionCoordinateSystem_swigregister(StepFEA_NodeWithSolutionCoordinateSystem)

class StepFEA_NodeWithVector(StepFEA_Node):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepFEA.StepFEA_NodeWithVector_swiginit(self, _StepFEA.new_StepFEA_NodeWithVector(*args))


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_NodeWithVector_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepFEA.delete_StepFEA_NodeWithVector

# Register StepFEA_NodeWithVector in _StepFEA:
_StepFEA.StepFEA_NodeWithVector_swigregister(StepFEA_NodeWithVector)

class StepFEA_HArray1OfCurveElementInterval(StepFEA_Array1OfCurveElementInterval, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HArray1OfCurveElementInterval_swiginit(self, _StepFEA.new_StepFEA_HArray1OfCurveElementInterval(*args))

    def Array1(self) -> "StepFEA_Array1OfCurveElementInterval const &":
        return _StepFEA.StepFEA_HArray1OfCurveElementInterval_Array1(self)

    def ChangeArray1(self) -> "StepFEA_Array1OfCurveElementInterval &":
        return _StepFEA.StepFEA_HArray1OfCurveElementInterval_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HArray1OfCurveElementInterval_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HArray1OfCurveElementInterval

# Register StepFEA_HArray1OfCurveElementInterval in _StepFEA:
_StepFEA.StepFEA_HArray1OfCurveElementInterval_swigregister(StepFEA_HArray1OfCurveElementInterval)

class StepFEA_HArray1OfCurveElementEndOffset(StepFEA_Array1OfCurveElementEndOffset, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HArray1OfCurveElementEndOffset_swiginit(self, _StepFEA.new_StepFEA_HArray1OfCurveElementEndOffset(*args))

    def Array1(self) -> "StepFEA_Array1OfCurveElementEndOffset const &":
        return _StepFEA.StepFEA_HArray1OfCurveElementEndOffset_Array1(self)

    def ChangeArray1(self) -> "StepFEA_Array1OfCurveElementEndOffset &":
        return _StepFEA.StepFEA_HArray1OfCurveElementEndOffset_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HArray1OfCurveElementEndOffset_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HArray1OfCurveElementEndOffset

# Register StepFEA_HArray1OfCurveElementEndOffset in _StepFEA:
_StepFEA.StepFEA_HArray1OfCurveElementEndOffset_swigregister(StepFEA_HArray1OfCurveElementEndOffset)

class StepFEA_HArray1OfElementRepresentation(StepFEA_Array1OfElementRepresentation, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HArray1OfElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_HArray1OfElementRepresentation(*args))

    def Array1(self) -> "StepFEA_Array1OfElementRepresentation const &":
        return _StepFEA.StepFEA_HArray1OfElementRepresentation_Array1(self)

    def ChangeArray1(self) -> "StepFEA_Array1OfElementRepresentation &":
        return _StepFEA.StepFEA_HArray1OfElementRepresentation_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HArray1OfElementRepresentation_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HArray1OfElementRepresentation

# Register StepFEA_HArray1OfElementRepresentation in _StepFEA:
_StepFEA.StepFEA_HArray1OfElementRepresentation_swigregister(StepFEA_HArray1OfElementRepresentation)

class StepFEA_HArray1OfCurveElementEndRelease(StepFEA_Array1OfCurveElementEndRelease, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HArray1OfCurveElementEndRelease_swiginit(self, _StepFEA.new_StepFEA_HArray1OfCurveElementEndRelease(*args))

    def Array1(self) -> "StepFEA_Array1OfCurveElementEndRelease const &":
        return _StepFEA.StepFEA_HArray1OfCurveElementEndRelease_Array1(self)

    def ChangeArray1(self) -> "StepFEA_Array1OfCurveElementEndRelease &":
        return _StepFEA.StepFEA_HArray1OfCurveElementEndRelease_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HArray1OfCurveElementEndRelease_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HArray1OfCurveElementEndRelease

# Register StepFEA_HArray1OfCurveElementEndRelease in _StepFEA:
_StepFEA.StepFEA_HArray1OfCurveElementEndRelease_swigregister(StepFEA_HArray1OfCurveElementEndRelease)

class StepFEA_HArray1OfDegreeOfFreedom(StepFEA_Array1OfDegreeOfFreedom, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HArray1OfDegreeOfFreedom_swiginit(self, _StepFEA.new_StepFEA_HArray1OfDegreeOfFreedom(*args))

    def Array1(self) -> "StepFEA_Array1OfDegreeOfFreedom const &":
        return _StepFEA.StepFEA_HArray1OfDegreeOfFreedom_Array1(self)

    def ChangeArray1(self) -> "StepFEA_Array1OfDegreeOfFreedom &":
        return _StepFEA.StepFEA_HArray1OfDegreeOfFreedom_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HArray1OfDegreeOfFreedom_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HArray1OfDegreeOfFreedom

# Register StepFEA_HArray1OfDegreeOfFreedom in _StepFEA:
_StepFEA.StepFEA_HArray1OfDegreeOfFreedom_swigregister(StepFEA_HArray1OfDegreeOfFreedom)

class StepFEA_HArray1OfNodeRepresentation(StepFEA_Array1OfNodeRepresentation, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HArray1OfNodeRepresentation_swiginit(self, _StepFEA.new_StepFEA_HArray1OfNodeRepresentation(*args))

    def Array1(self) -> "StepFEA_Array1OfNodeRepresentation const &":
        return _StepFEA.StepFEA_HArray1OfNodeRepresentation_Array1(self)

    def ChangeArray1(self) -> "StepFEA_Array1OfNodeRepresentation &":
        return _StepFEA.StepFEA_HArray1OfNodeRepresentation_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HArray1OfNodeRepresentation_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HArray1OfNodeRepresentation

# Register StepFEA_HArray1OfNodeRepresentation in _StepFEA:
_StepFEA.StepFEA_HArray1OfNodeRepresentation_swigregister(StepFEA_HArray1OfNodeRepresentation)

class StepFEA_HSequenceOfElementRepresentation(StepFEA_SequenceOfElementRepresentation, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HSequenceOfElementRepresentation_swiginit(self, _StepFEA.new_StepFEA_HSequenceOfElementRepresentation(*args))

    def Sequence(self) -> "StepFEA_SequenceOfElementRepresentation const &":
        return _StepFEA.StepFEA_HSequenceOfElementRepresentation_Sequence(self)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_HSequenceOfElementRepresentation_Append(self, *args)

    def ChangeSequence(self) -> "StepFEA_SequenceOfElementRepresentation &":
        return _StepFEA.StepFEA_HSequenceOfElementRepresentation_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HSequenceOfElementRepresentation_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HSequenceOfElementRepresentation

# Register StepFEA_HSequenceOfElementRepresentation in _StepFEA:
_StepFEA.StepFEA_HSequenceOfElementRepresentation_swigregister(StepFEA_HSequenceOfElementRepresentation)

class StepFEA_HSequenceOfElementGeometricRelationship(StepFEA_SequenceOfElementGeometricRelationship, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HSequenceOfElementGeometricRelationship_swiginit(self, _StepFEA.new_StepFEA_HSequenceOfElementGeometricRelationship(*args))

    def Sequence(self) -> "StepFEA_SequenceOfElementGeometricRelationship const &":
        return _StepFEA.StepFEA_HSequenceOfElementGeometricRelationship_Sequence(self)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_HSequenceOfElementGeometricRelationship_Append(self, *args)

    def ChangeSequence(self) -> "StepFEA_SequenceOfElementGeometricRelationship &":
        return _StepFEA.StepFEA_HSequenceOfElementGeometricRelationship_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HSequenceOfElementGeometricRelationship_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HSequenceOfElementGeometricRelationship

# Register StepFEA_HSequenceOfElementGeometricRelationship in _StepFEA:
_StepFEA.StepFEA_HSequenceOfElementGeometricRelationship_swigregister(StepFEA_HSequenceOfElementGeometricRelationship)

class StepFEA_HSequenceOfNodeRepresentation(StepFEA_SequenceOfNodeRepresentation, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HSequenceOfNodeRepresentation_swiginit(self, _StepFEA.new_StepFEA_HSequenceOfNodeRepresentation(*args))

    def Sequence(self) -> "StepFEA_SequenceOfNodeRepresentation const &":
        return _StepFEA.StepFEA_HSequenceOfNodeRepresentation_Sequence(self)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_HSequenceOfNodeRepresentation_Append(self, *args)

    def ChangeSequence(self) -> "StepFEA_SequenceOfNodeRepresentation &":
        return _StepFEA.StepFEA_HSequenceOfNodeRepresentation_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HSequenceOfNodeRepresentation_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HSequenceOfNodeRepresentation

# Register StepFEA_HSequenceOfNodeRepresentation in _StepFEA:
_StepFEA.StepFEA_HSequenceOfNodeRepresentation_swigregister(StepFEA_HSequenceOfNodeRepresentation)

class StepFEA_HSequenceOfCurve3dElementProperty(StepFEA_SequenceOfCurve3dElementProperty, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepFEA.StepFEA_HSequenceOfCurve3dElementProperty_swiginit(self, _StepFEA.new_StepFEA_HSequenceOfCurve3dElementProperty(*args))

    def Sequence(self) -> "StepFEA_SequenceOfCurve3dElementProperty const &":
        return _StepFEA.StepFEA_HSequenceOfCurve3dElementProperty_Sequence(self)

    def Append(self, *args) -> "void":
        return _StepFEA.StepFEA_HSequenceOfCurve3dElementProperty_Append(self, *args)

    def ChangeSequence(self) -> "StepFEA_SequenceOfCurve3dElementProperty &":
        return _StepFEA.StepFEA_HSequenceOfCurve3dElementProperty_ChangeSequence(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepFEA_HSequenceOfCurve3dElementProperty_DownCast(t)

    __swig_destroy__ = _StepFEA.delete_StepFEA_HSequenceOfCurve3dElementProperty

# Register StepFEA_HSequenceOfCurve3dElementProperty in _StepFEA:
_StepFEA.StepFEA_HSequenceOfCurve3dElementProperty_swigregister(StepFEA_HSequenceOfCurve3dElementProperty)





